/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |                (DATASET 0006:  12-MONTH FOLLOW-UP DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0006-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0006"

#delimit ;
label define MDA_MO    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MFIRE     50 "COMPLETED" 51 "PARTIAL" 52 "DECEASED"
                       60 "UNABLE TO LOCATE" 70 "REFUSAL"
                       80 "PHYSICALLY/MENTALLY" 81 "LANGUAGE BARRIER"
                       82 "INCARCERATED/ETC." 90 "OTHER" ;
label define MTOLE     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MTS_HH    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MTS_MM    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MTSAMPM   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;
label define MA1       -8 "BLANK/MISSING" -7 "REFUSAL" -6 "MULTIPLE RESPONSE"
                       -5 "BAD DATA" -4 "DONT KNOW" -3 "NOT APPLICABLE"
                       -2 "RESPONSE ILLEGIBLE" 1 "MALE" 2 "FEMALE" ;
label define MA2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MA5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A ONE-FAMILY HOUSE/DUPLEX/CONDO"
                       2 "A MOBILE HOME OR TRAILER"
                       3 "APARTMENT/MULTIPLE FAMILY BUILDING"
                       4 "HOTEL/ROOMING/BOARDING HOUSE"
                       5 "A HOSPITAL/MEDICAL INSTITUTION"
                       6 "IN JAIL/PRISON/DETENTION HOME"
                       7 "RESIDENTIAL DRUG TX CENTER"
                       8 "SOME OTHER GROUP RESIDENCE"
                       9 "IN A HOMELESS SHELTER" 10 "ON THE STREET"
                       11 "OTHER" ;
label define MA6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MA7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MARRIED" 2 "LEGALLY SEPARATED" 3 "DIVORCED"
                       4 "WIDOWED" 5 "LIVING WITH SOMEONE AS MARRIED"
                       6 "NEVER MARRIED" ;
label define MA8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "W/SPOUSE OR SEXUAL PARTNER/CHILDREN"
                       2 "WITH SPOUSE OR SEXUAL PARTNER ONLY"
                       3 "WITH CHILDREN ONLY" 4 "WITH BOTH PARENTS"
                       5 "WITH MOTHER ONLY" 6 "WITH FATHER ONLY"
                       7 "WITH PARENT(S) AND OWN CHILDREN"
                       8 "W/OTHER FAMILY ONLY/COMBINATION 01-07"
                       9 "WITH FOSTER PARENTS"
                       10 "W/FAMILY/FRIENDS/BOARDERS/ROOMMATE"
                       11 "WITH FRIENDS OR ROOMMATE ONLY" 12 "ALONE"
                       13 "INSTITUTION OR CLOSED FACILITY"
                       14 "NO STABLE ARRANGEMENTS" 15 "OTHER" ;
label define MA9_0     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MA9_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MA9A_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define MA9B_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9C_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9D_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MA9A_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define MA9B_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9C_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9D_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MA9A_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define MA9B_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9C_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9D_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MA9A_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define MA9B_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9C_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9D_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MA9A_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY" ;
label define MA9B_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9C_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA9D_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "LESS THAN ONCE A MONTH" 2 "ABOUT ONCE A MONTH"
                       3 "2 TO 3 TIMES A MONTH" 4 "ONCE A MONTH"
                       5 "MORE THAN ONCE A WEEK" ;
label define MA11A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS THAN ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define MA11B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS THAN ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define MA11C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS THAN ONCE A WEEK"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define MA12A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12F     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA12G     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "ONE OR A FEW" 2 "MANY" ;
label define MA13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA14_0    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MA14_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MA14_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MA14_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MA14_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MA14_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MA14_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MA14_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MA14_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MA14_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MA15      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MA15A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PRETRIAL DIVERSION" 2 "PRETRIAL INTERVENTION"
                       3 "PRESENTENCE REFERRAL" 4 "CONDITIONAL PROBATION"
                       5 "CONDITIONAL PAROLE" 6 "OTHER SUPERVISION" ;
label define MB1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DATE CORRECT" 2 "NO, DATE INCORRECT" ;
label define MB1A_MO   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MB1A_YR   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MB2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TREATMENT" 1 "COMPLETED"
                       2 "LEFT BEFORE COMPLETION" ;
label define MB2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WENT TO JAIL OR PRISON" 2 "WENT INTO HOSPITAL"
                       3 "NONCOMPLIANCE WITH RULES" 4 "POOR PERFORMANCE"
                       9 "OTHER DISCHARGE REASON"
                       11 "TRANSFERRED TO ANOTHER PROGRAM"
                       12 "TRANSFERRED TO ANOTHER AGENCY"
                       19 "OTHER TRANSFER REASON"
                       21 "MOVED FROM SERVICE AREA"
                       22 "CRIMINAL JUSTICE PRESSURE CEASED"
                       23 "COULD CONTROL DRUG USE MYSELF"
                       24 "DRUGS BECAME AVAILABLE ON STREET"
                       25 "STARTED USING COCAINE AGAIN"
                       26 "STARTD USINGOTHER DRUGS/NOT COCAINE"
                       27 "DIFFICULTIES WITH TRANSPORTATION"
                       28 "DIFFICULTIES WITH CHILD CARE"
                       29 "OTHER PERSONAL REASON"
                       31 "INSURANCE COVERAGE RAN OUT"
                       32 "UNABLE TO PAY FOR TX"
                       33 "NEEDED TO GET BACK TO WORK"
                       39 "OTHER FINANCIAL REASON" 41 "PROGRAM NOT HELPFUL"
                       42 "INADEQUATE SERVICES" 43 "CONFLICT WITH STAFF"
                       44 "PROGRAM WAS GOING TO TERMINATE CLIENT"
                       45 "INTAKE INTERVWS WERE TOO BURDENSOME"
                       49 "OTHER PROGRAM DISSATISFACTION" 59 "OTHER REASON" ;
label define MB2B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB2C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "DONT KNOW" ;
label define MB3A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB3B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB3C_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MB3C_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MB3C_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MB3C_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MB3C_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MB3C_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MB3C_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MB3C_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MB4_0     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MB4_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MB4_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MB4_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MB4_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MB4_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MB4_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MB4_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MB4_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MB4_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MB5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "DIFFERENT RELATIONSHIPS" ;
label define MB6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "AS LITTLE AS POSSIBLE" 2 "TO SOME EXTENT"
                       3 "PRETTY CLOSELY" 4 "VERY CLOSELY" ;
label define MB7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SATISFIED" ;
label define MB8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB11A_1   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MB11A_2   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MB11A_3   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MB11A_4   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MB11A_5   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MB11A_6   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MB11A_7   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MB11A_8   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MB12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MB13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MB14B_10  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_20  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_30  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_40  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_41  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_42  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_50  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_60  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_70  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_80  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB14B_90  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MB15      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "DRUG USE DID NOT CAUSE PROB" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, OR THC"
                       30 "HALLUCINOGENS OR PSYHCEDELICS"
                       40 "COCAINE IN ANY FORM/CRACK" 41 "CRACK ONLY"
                       42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       60 "NARCOTICS OR OPIATES" 70 "DOWNERS OR DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       90 "ANY OTHER DRUG" ;
label define MB16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB18      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB18A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB19      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB19A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MB19B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB22      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB23      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WORKING AT LEGITIMATE JOB"
                       2 "HAD A JOB BUT WAS NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "KEEPING HOUSE FOR YOURSELF/FAMILY"
                       5 "GOING TO SCHOOL OR TRAINING PROGRAM"
                       6 "UNABLE TO WORK, DISABLED" 7 "RETIRED"
                       8 "IN JAIL, RESIDENTIAL TX PROGRAM"
                       9 "INVOLVED IN DRUG-RELATED ACTIVITIES"
                       10 "INVOLVED INOTHER ILLEGAL ACTIVITIES"
                       11 "NOT WORKING/NOT INTERESTED IN WORK" 12 "OTHER" ;
label define MB23_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING"
                       -3 "NOT APPLICABLE" 1 "(01A) 35 HRS. OR MORE A WEEK"
                       2 "(01B) < 35 HRS. A WEEK" ;
label define MB24      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB25      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MB26      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MB26A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" 3 "PROGRAM CHARGES NO FEES"
                       4 "PARTIALLY COVERED" ;
label define MC1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SHORTAGE OF AVAILABLE DRUGS"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUY OTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFE-STYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFE-STYLE"
                       31 "HAVE DRUG-RELATED DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS"
                       34 "HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASONS"
                       41 "WANT TO SAVE MY MARRIAGE"
                       42 "WANT TO IMPROVE RELATIONS W/FAMILY"
                       43 "WANT TO AVOID LOSING CHILD CUSTODY"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "AVOID INVOLVEMENT CRIMINAL ACTIVITY"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE AN UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "BECOME ELIGIBLE PUBLIC ASSISTANCE"
                       62 "BECOME ELIGIBLE MEDICAL SERVICES"
                       63 "BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB/FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY BOSS"
                       73 "TO PREVENT PROBS W/CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL"
                       77 "PREVENT PROBS W/OTHR STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY MEMBERS" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define MC2_0     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MC2_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MC2_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MC2_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MC2_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MC2_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MC2_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MC2_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MC2_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MC2_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MC3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEITHER REQUIRED NOR SUGGESTED"
                       1 "REQUIRED/STIPULATED" 2 "SUGGESTED/ENCOURAGED" ;
label define MC4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WORKING AT LEGITIMATE JOB"
                       2 "HAD A JOB BUT WAS NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "KEEPING HOUSE FOR YOURSELF/FAMILY"
                       5 "GOING TO SCHOOL OR TRAINING PROGRAM"
                       6 "UNABLE TO WORK, DISABLED" 7 "RETIRED"
                       8 "IN JAIL, RESIDENTIAL TX PROGRAM"
                       9 "INVOLVED IN DRUG-RELATED ACTIVITIES"
                       10 "INVOLVED IN OTHER ILLEGAL ACTIVITIES"
                       11 "NOT WORKING/NOT INTERESTED IN WORK" 12 "OTHER" ;
label define MC4_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING"
                       -6 "MULTIPLE RESPONSE" -3 "NOT APPLICABLE"
                       1 "(01A) 35 HRS. OR MORE A WEEK"
                       2 "(01B) < 35 HRS. A WEEK" ;
label define MC5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVE" 7 "TRANSPORTATION EQUIPMENT OPERATIVE"
                       8 "NONFARM LABOR" 9 "PRIVATE HOUSEHOLD WORKER"
                       10 "SERVICE WORKER" 11 "FARMER AND FARM MANAGER"
                       12 "FARM LABORER" 20 "MILITARY SERVICE" 86 "OTHER" ;
label define MC6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL, NONE" 1 "LESS THAN 1 DAY A MONTH"
                       2 "1 TO 3 DAYS A MONTH" 3 "1 TO 2 DAYS A WEEK"
                       4 "3 TO 4 DAYS A WEEK" 5 "5 TO 6 DAYS A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 TO 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" ;
label define MC6A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC9_20    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_30    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_40    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_41    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_42    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_50    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_60    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_70    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_80    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC9_90    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED AT ALL DURING THE PERIOD"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERYDAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define MC10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO FAVORITE DRUG" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, OR THC"
                       30 "HALLUCINOGENS OR PSYHCEDELICS"
                       40 "COCAINE IN ANY FORM/CRACK" 41 "CRACK ONLY"
                       42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       60 "NARCOTICS OR OPIATES" 70 "DOWNERS OR DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       90 "ANY OTHER DRUG" ;
label define MC11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO PROB DRUG" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, OR THC"
                       30 "HALLUCINOGENS OR PSYHCEDELICS"
                       40 "COCAINE IN ANY FORM/CRACK" 41 "CRACK ONLY"
                       42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       60 "NARCOTICS OR OPIATES" 70 "DOWNERS OR DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       90 "ANY OTHER DRUG" ;
label define MC12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AA    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BA    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC14B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AB    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BB    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC14C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AC    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BC    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC14D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AD    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BD    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC14E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AE    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BE    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC14F     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC14AF    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 55 "55+" ;
label define MC14BF    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_10   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_10   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_10   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC15_12   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC16_12   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC17_12   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MC18      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "LESS THAN ONE DAY A MONTH" 2 "1 TO 3 DAYS A MONTH"
                       3 "1 TO 2 DAYS A WEEK" 4 "3 TO 4 DAYS A WEEK"
                       5 "5 TO 6 DAYS A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY" ;
label define MC19      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC22      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MC22A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MD1A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "DIPLOMA" 2 "GED" ;
label define MD3_0     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MD3_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MD3_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MD3_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MD3_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MD3_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MD3_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MD4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD4A_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MD4A_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MD4A_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MD4A_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MD4A_5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MD4A_6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MD4A_7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MD4A_8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MD4A_11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MD5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "DRIVE"
                       2 "PUBLIC TRANSPORTATION" 3 "RIDE FROM FAMILY/FRIEND"
                       4 "TAXICAB" 5 "OTHER" ;
label define MD6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD6A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD6B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MD6D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "EXPIRED" 2 "SUSPENDED" 3 "REVOKED" ;
label define MD7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NONE"
                       1 "SOME" 2 "ALL OF THE TIME" ;
label define ME1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL, NONE" 1 "LESS THAN 1 DAY A MONTH"
                       2 "1 TO 3 DAYS A MONTH" 3 "1 TO 2 DAYS A WEEK"
                       4 "3 TO 4 DAYS A WEEK" 5 "5 TO 6 DAYS A WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2 TO 3 TIMES A DAY"
                       8 "4 OR MORE TIMES A DAY" 9 "OTHER" ;
label define ME4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define ME13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define ME14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME14A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1/2 PACK A DAY" 2 "ABOUT 1/2 PACK A DAY"
                       3 "ABOUT A PACK A DAY" 4 "ABOUT 1 1/2 PACKS A DAY"
                       5 "ABOUT 2 PACKS OR MORE A DAY" ;
label define ME15_0    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define ME15_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define ME15_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define ME15_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define ME16_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME21_20   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME21_30   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_31   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_31   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_31   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_32   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_32   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_32   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_40   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_41   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_41   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_41   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_42   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_42   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_42   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_50   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_51   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_51   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_51   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_60   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_61   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_61   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_61   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_62   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_62   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_62   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_70   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_71   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME16_72   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME16_73   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME16_74   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME16_75   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME16_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_80   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_81   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_81   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_81   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME17_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME18_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY MOUTH" 2 "BY SMOKING IT"
                       3 "BY INHALING,SNORTING,OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "BY FREEBASING"
                       7 "SOME OTHER WAY" ;
label define ME19_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME20_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_90   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME16_92   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME20_92   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "PAST WEEK" 1 "1 WEEK AGO" 2 "2 WEEKS AGO..." ;
label define ME21_92   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN ONCE A MONTH" 2 "1 TO 3 TIMES A MONTH"
                       3 "1 TO 2 TIMES A WEEK" 4 "3 TO 4 TIMES A WEEK"
                       5 "5 TO 6 TIMES A WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2 TO 3 TIMES A DAY" 8 "4 OR MORE TIMES A DAY"
                       9 "OTHER" ;
label define ME22_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED IN PAST 3 DAYS"
                       20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM, INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBITURATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME22_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED IN PAST 3 DAYS"
                       20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBITURATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME22_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED IN PAST 3 DAYS"
                       20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBITURATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME22_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT USED IN PAST 3 DAYS"
                       20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBITURATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME23      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO PROBS" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBUTYRATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "OTHER DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME24      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "BY YOURSELF" 2 "WITH 1 OR 2 OTHER PEOPLE"
                       3 "IN A GROUP" ;
label define ME25      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "AT HOME" 2 "AT FRIENDS/RELATIVES HOME"
                       3 "AT A SHOOTING GALLERY" 4 "ON THE STREET"
                       5 "IN A MOTOR VEHICLE" 6 "SOME OTHER PLACE" ;
label define ME27      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME27A1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBUTYRATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "OTHER DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME27A2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBUTYRATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "OTHER DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME27A3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH OR THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS" 31 "PCP" 32 "LSD"
                       40 "COCAINE IN ANY FORM,INCLUDING CRACK"
                       41 "CRACK ONLY" 42 "ANY COCAINE OTHER THAN CRACK"
                       50 "HEROIN ALONE OR WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER"
                       60 "NARCOTICS OR OPIATES"
                       61 "STREET OR ILLEGAL METHADONE" 62 "DILAUDID"
                       70 "DOWNERS OR DEPRESSANTS"
                       71 "SEDATIVES OR SLEEPING PILLS" 72 "BARBUTYRATES"
                       73 "BENZODIAZEPINES" 74 "OTHER TRANQUILIZERS"
                       75 "OTHER DEPRESSANTS"
                       80 "AMPHETAMINES OR OTHER STIMULANTS"
                       81 "METHAMPHETAMINES" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define ME28      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME29      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME29A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME30A_1   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30A_2   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30A_3   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30A_4   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30A_5   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME30A_6   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME31      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME31A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME31B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME32A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME32B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME32C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME32D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME32E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME32F     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "RARELY" 2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define ME33A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33F     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME33G     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME34      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME35      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "VERY WEAK" 5 "MODERATE" 10 "VERY STRONG" ;
label define ME36      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A FEW SECONDS" 2 "A FEW MINUTES"
                       3 "ABOUT 15 MINUTES" 4 "ABOUT 1/2 AN HOUR"
                       5 "CLOSE TO 1 HOUR" 6 "AN HOUR OR LONGER" ;
label define ME37      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define ME38      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define ME39      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define ME40      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY IMPORTANT" ;
label define ME41      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SHORTAGE OF AVAILABLE DRUGS"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUYOTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFE-STYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFE-STYLE"
                       31 "HAVE DRUG-RELATED DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS"
                       34 "HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON" 41 "WANT TO SAVE MY MARRIAGE"
                       42 "WANT TO IMPROVE RELATIONS W/FAMILY"
                       43 "WANT TO AVOID LOSING CHILD CUSTODY"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "AVOID INVOLVEMENT CRIMINAL ACTIVITY"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE AN UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "BECOME ELIGIBLE PUBLIC ASSISTANCE"
                       62 "BECOME ELIGIBLE MEDICAL SERVICES"
                       63 "BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB/FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY BOSS"
                       73 "TO PREVENT PROBS W/CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL"
                       77 "PREVENT PROBS W/OTHR STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY MEMBERS" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define ME41A1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SHORTAGE OF AVAILABLE DRUGS"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUYOTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFE-STYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFE-STYLE"
                       31 "HAVE DRUG-RELATED DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS"
                       34 "HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON" 41 "WANT TO SAVE MY MARRIAGE"
                       42 "WANT TO IMPROVE RELATIONS W/FAMILY"
                       43 "WANT TO AVOID LOSING CHILD CUSTODY"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "AVOID INVOLVEMENT CRIMINAL ACTIVITY"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE AN UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "BECOME ELIGIBLE PUBLIC ASSISTANCE"
                       62 "BECOME ELIGIBLE MEDICAL SERVICES"
                       63 "BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB/FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY BOSS"
                       73 "TO PREVENT PROBS W/CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL"
                       77 "PREVENT PROBS W/OTHER STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY MEMBERS" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define ME41A2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SHORTAGE OF AVAILABLE DRUGS"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUYOTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFE-STYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFE-STYLE"
                       31 "HAVE DRUG-RELATED DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS"
                       34 "HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON" 41 "WANT TO SAVE MY MARRIAGE"
                       42 "WANT TO IMPROVE RELATIONS W/FAMILY"
                       43 "WANT TO AVOID LOSING CHILD CUSTODY"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "AVOID INVOLVEMENT CRIMINAL ACTIVITY"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE AN UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "BECOME ELIGIBLE PUBLIC ASSISTANCE"
                       62 "BECOME ELIGIBLE MEDICAL SERVICES"
                       63 "BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB/FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY BOSS"
                       73 "TO PREVENT PROBS W/CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL"
                       77 "PREVENT PROBS W/OTHR STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY MEMBERS" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define ME41A3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SHORTAGE OF AVAILABLE DRUGS"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUYOTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFE-STYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFE-STYLE"
                       31 "HAVE DRUG-RELATED DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS"
                       34 "HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON" 41 "WANT TO SAVE MY MARRIAGE"
                       42 "WANT TO IMPROVE RELATIONS W/FAMILY"
                       43 "WANT TO AVOID LOSING CHILD CUSTODY"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "AVOID INVOLVEMENT CRIMINAL ACTIVITY"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE AN UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "BECOME ELIGIBLE PUBLIC ASSISTANCE"
                       62 "BECOME ELIGIBLE MEDICAL SERVICES"
                       63 "BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB/FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY BOSS"
                       73 "TO PREVENT PROBS W/CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL"
                       77 "PREVENT PROBS W/OTHR STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY MEMBERS" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define ME42A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42F     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42G     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42H     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42I     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42J     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42K     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42L     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42M     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42N     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42O     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42P     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42Q     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42R     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42S     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME42T     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME43      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME43A1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "50% OF THE TIME" 2 "AFTER DREAMING ABOUT DRUGS"
                       3 "AFTER HAVING MY BABY" 4 "ALL THE TIME"
                       5 "AN ATTRACTIVE WOMAN" 6 "ANGER" 7 "ANYTIME"
                       8 "ARGUING WITH FAMILY/FRIENDS" 9 "AT A BAR"
                       10 "AT WORK" 11 "ATTITUDE"
                       12 "BAD SELF-ESTEEM/LOW SELF-ESTEEM" 13 "BEING ALONE"
                       14 "BEING IN A PHARMACY" 15 "BILLS/DEBTS" 16 "BORED"
                       17 "CANT COPE WITH THINGS" 18 "CANT SLEEP"
                       19 "CONFUSION" 20 "CONVENIENCE" 21 "CSD"
                       22 "DEATH OF FRIEND/FAMILY" 23 "DEPRESSION"
                       24 "DETOXING" 25 "DISGUSTED" 26 "END OF WORK WEEK"
                       27 "ENVIRONMENT W/DRUGS/OTHERS USING/AVAILAB"
                       28 "EVERYDAY" 29 "EXTRA MONEY" 30 "FAMILY"
                       31 "FAMILY PROBLEMS" 32 "FAMILY REUNION"
                       33 "FLASHBACK" 34 "FREEBIES" 35 "FRIENDS"
                       36 "FULL MOON" 37 "GAMBLING" 38 "GIVING UP HOPE"
                       39 "GO BACK TO OLD NEIGHBORHOOD"
                       40 "GOING PAST DENTIST OFFICE" 41 "GOING THRU CHANGES"
                       42 "GOING TO STORE" 43 "HAPPY" 44 "HOLIDAYS"
                       45 "HOT DAY" 46 "HYPER"
                       47 "IF I DONT STAY IN THE PROGRAM"
                       48 "IF I HAVE A CAR" 49 "IF IM IN JAIL"
                       50 "IN PRESENCE OF POLICE OFFICER" 51 "KIDS"
                       52 "LOSS OF BOYFRIEND/GIRLFRIEND/BREAKUP"
                       53 "LOSS OF HOPE" 54 "LOSS OF JOB OR ASSETS"
                       55 "MEDICAL REASONS" 56 "MIND IS WANDERING"
                       57 "MOOD CHANGES"
                       58 "NEAR/RIGHT AFTER PAY DAY/NO $ LEFT"
                       59 "NEED COMFORT/LOVE" 60 "NERVOUS/EDGY/IRRITABLE"
                       61 "NIGHT TIME" 62 "NO MONEY" 63 "NOISES"
                       64 "NOT WORKING" 65 "ON THE WEEKEND" 66 "P.M.S."
                       67 "PAIN/SICK" 68 "PARAPHERNALIA" 69 "PARTY"
                       70 "PLAYING MUSIC" 71 "PROBLEMS"
                       72 "PROBLEMS W/SPOUSE" 73 "REJECTION"
                       74 "RELATIONSHIPS" 75 "RELAXED"
                       76 "REMEMBER HOW IT MADE ME FEEL" 77 "SAD"
                       78 "SEEING CRACK USED ON TV"
                       79 "SELLING OF DRUGS/FINANCIAL" 80 "SEXUALLY"
                       81 "SNEAKY" 82 "SOMEONE HANDED IT TO ME"
                       83 "SPORTING EVENTS" 84 "STRESSED"
                       85 "TALKING ABOUT DRUGS" 86 "THERE"
                       87 "THINKING ABOUT CHILDHOOD ABUSE"
                       88 "THINKING ABOUT ILLNESS" 89 "TRAGEDY IN FAMILY"
                       90 "TRIGGERS" 91 "UNDER PRESSURE"
                       92 "UNEXPECTED CRAVINGS" 93 "VACATION"
                       94 "WANT A REWARD" 95 "WANT TO FEEL GOOD"
                       96 "WHEN RESPONDENT HAS THE MONEY"
                       97 "WHEN DENIED SOMETHING"
                       98 "WHEN FEELING ON TOP OF THE WORLD"
                       99 "WHEN FRIGHTENED" 100 "WHEN I DRINK/SMOKE"
                       101 "WHEN I HAVE DRUGS/RUN UP ON DRUGS HIDDEN"
                       102 "WHEN I HAVENT DONE DRUGS IN AWHILE"
                       103 "WHEN I LEAVE JAIL"
                       104 "WHEN I THINK I CAN RUN THE SHOW"
                       105 "WHEN I WAKE UP"
                       106 "WHEN I WALK INTO A PUBLIC BATHROOM"
                       107 "WHEN IM TIRED" 108 "WHEN PEOPLE DRINK/SMOKE"
                       109 "WHEN SATISFIED" 110 "WHEN THINGS ARE GOING BAD"
                       111 "WHEN THINGS ARE GOING GOOD"
                       112 "WHEN THINKING ABOUT DRUGS"
                       113 "W/BOYFRIEND/GIRLFRIEND/HUSBAND/WIFE"
                       114 "WORK PROBLEMS" ;
label define ME43A2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "50% OF THE TIME" 2 "AFTER DREAMING ABOUT DRUGS"
                       3 "AFTER HAVING MY BABY" 4 "ALL THE TIME"
                       5 "AN ATTRACTIVE WOMAN" 6 "ANGER" 7 "ANYTIME"
                       8 "ARGUING WITH FAMILY/FRIENDS" 9 "AT A BAR"
                       10 "AT WORK" 11 "ATTITUDE"
                       12 "BAD SELF-ESTEEM/LOW SELF-ESTEEM" 13 "BEING ALONE"
                       14 "BEING IN A PHARMACY" 15 "BILLS/DEBTS" 16 "BORED"
                       17 "CANT COPE WITH THINGS" 18 "CANT SLEEP"
                       19 "CONFUSION" 20 "CONVENIENCE" 21 "CSD"
                       22 "DEATH OF FRIEND/FAMILY" 23 "DEPRESSION"
                       24 "DETOXING" 25 "DISGUSTED" 26 "END OF WORK WEEK"
                       27 "ENVIRONMENT W/DRUGS/OTHERS USING/AVAILAB"
                       28 "EVERYDAY" 29 "EXTRA MONEY" 30 "FAMILY"
                       31 "FAMILY PROBLEMS" 32 "FAMILY REUNION"
                       33 "FLASHBACK" 34 "FREEBIES" 35 "FRIENDS"
                       36 "FULL MOON" 37 "GAMBLING" 38 "GIVING UP HOPE"
                       39 "GO BACK TO OLD NEIGHBORHOOD"
                       40 "GOING PAST DENTIST OFFICE" 41 "GOING THRU CHANGES"
                       42 "GOING TO STORE" 43 "HAPPY" 44 "HOLIDAYS"
                       45 "HOT DAY" 46 "HYPER"
                       47 "IF I DONT STAY IN THE PROGRAM"
                       48 "IF I HAVE A CAR" 49 "IF IM IN JAIL"
                       50 "IN PRESENCE OF POLICE OFFICER" 51 "KIDS"
                       52 "LOSS OF BOYFRIEND/GIRLFRIEND/BREAKUP"
                       53 "LOSS OF HOPE" 54 "LOSS OF JOB OR ASSETS"
                       55 "MEDICAL REASONS" 56 "MIND IS WANDERING"
                       57 "MOOD CHANGES"
                       58 "NEAR/RIGHT AFTER PAY DAY/NO $ LEFT"
                       59 "NEED COMFORT/LOVE" 60 "NERVOUS/EDGY/IRRITABLE"
                       61 "NIGHT TIME" 62 "NO MONEY" 63 "NOISES"
                       64 "NOT WORKING" 65 "ON THE WEEKEND" 66 "P.M.S."
                       67 "PAIN/SICK" 68 "PARAPHERNALIA" 69 "PARTY"
                       70 "PLAYING MUSIC" 71 "PROBLEMS"
                       72 "PROBLEMS W/SPOUSE" 73 "REJECTION"
                       74 "RELATIONSHIPS" 75 "RELAXED"
                       76 "REMEMBER HOW IT MADE ME FEEL" 77 "SAD"
                       78 "SEEING CRACK USED ON TV"
                       79 "SELLING OF DRUGS/FINANCIAL" 80 "SEXUALLY"
                       81 "SNEAKY" 82 "SOMEONE HANDED IT TO ME"
                       83 "SPORTING EVENTS" 84 "STRESSED"
                       85 "TALKING ABOUT DRUGS" 86 "THERE"
                       87 "THINKING ABOUT CHILDHOOD ABUSE"
                       88 "THINKING ABOUT ILLNESS" 89 "TRAGEDY IN FAMILY"
                       90 "TRIGGERS" 91 "UNDER PRESSURE"
                       92 "UNEXPECTED CRAVINGS" 93 "VACATION"
                       94 "WANT A REWARD" 95 "WANT TO FEEL GOOD"
                       96 "WHEN RESPONDENT HAS THE MONEY"
                       97 "WHEN DENIED SOMETHING"
                       98 "WHEN FEELING ON TOP OF THE WORLD"
                       99 "WHEN FRIGHTENED" 100 "WHEN I DRINK/SMOKE"
                       101 "WHEN I HAVE DRUGS/RUN UP ON DRUGS HIDDEN"
                       102 "WHEN I HAVENT DONE DRUGS IN AWHILE"
                       103 "WHEN I LEAVE JAIL"
                       104 "WHEN I THINK I CAN RUN THE SHOW"
                       105 "WHEN I WAKE UP"
                       106 "WHEN I WALK INTO A PUBLIC BATHROOM"
                       107 "WHEN IM TIRED" 108 "WHEN PEOPLE DRINK/SMOKE"
                       109 "WHEN SATISFIED" 110 "WHEN THINGS ARE GOING BAD"
                       111 "WHEN THINGS ARE GOING GOOD"
                       112 "WHEN THINKING ABOUT DRUGS"
                       113 "W/BOYFRIEND/GIRLFRIEND/HUSBAND/WIFE"
                       114 "WORK PROBLEMS" ;
label define ME43A3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "50% OF THE TIME" 2 "AFTER DREAMING ABOUT DRUGS"
                       3 "AFTER HAVING MY BABY" 4 "ALL THE TIME"
                       5 "AN ATTRACTIVE WOMAN" 6 "ANGER" 7 "ANYTIME"
                       8 "ARGUING WITH FAMILY/FRIENDS" 9 "AT A BAR"
                       10 "AT WORK" 11 "ATTITUDE"
                       12 "BAD SELF-ESTEEM/LOW SELF-ESTEEM" 13 "BEING ALONE"
                       14 "BEING IN A PHARMACY" 15 "BILLS/DEBTS" 16 "BORED"
                       17 "CANT COPE WITH THINGS" 18 "CANT SLEEP"
                       19 "CONFUSION" 20 "CONVENIENCE" 21 "CSD"
                       22 "DEATH OF FRIEND/FAMILY" 23 "DEPRESSION"
                       24 "DETOXING" 25 "DISGUSTED" 26 "END OF WORK WEEK"
                       27 "ENVIRONMENT W/DRUGS/OTHERS USING/AVAILAB"
                       28 "EVERYDAY" 29 "EXTRA MONEY" 30 "FAMILY"
                       31 "FAMILY PROBLEMS" 32 "FAMILY REUNION"
                       33 "FLASHBACK" 34 "FREEBIES" 35 "FRIENDS"
                       36 "FULL MOON" 37 "GAMBLING" 38 "GIVING UP HOPE"
                       39 "GO BACK TO OLD NEIGHBORHOOD"
                       40 "GOING PAST DENTIST OFFICE" 41 "GOING THRU CHANGES"
                       42 "GOING TO STORE" 43 "HAPPY" 44 "HOLIDAYS"
                       45 "HOT DAY" 46 "HYPER"
                       47 "IF I DONT STAY IN THE PROGRAM"
                       48 "IF I HAVE A CAR" 49 "IF IM IN JAIL"
                       50 "IN PRESENCE OF POLICE OFFICER" 51 "KIDS"
                       52 "LOSS OF BOYFRIEND/GIRLFRIEND/BREAKUP"
                       53 "LOSS OF HOPE" 54 "LOSS OF JOB OR ASSETS"
                       55 "MEDICAL REASONS" 56 "MIND IS WANDERING"
                       57 "MOOD CHANGES"
                       58 "NEAR/RIGHT AFTER PAY DAY/NO $ LEFT"
                       59 "NEED COMFORT/LOVE" 60 "NERVOUS/EDGY/IRRITABLE"
                       61 "NIGHT TIME" 62 "NO MONEY" 63 "NOISES"
                       64 "NOT WORKING" 65 "ON THE WEEKEND" 66 "P.M.S."
                       67 "PAIN/SICK" 68 "PARAPHERNALIA" 69 "PARTY"
                       70 "PLAYING MUSIC" 71 "PROBLEMS"
                       72 "PROBLEMS W/SPOUSE" 73 "REJECTION"
                       74 "RELATIONSHIPS" 75 "RELAXED"
                       76 "REMEMBER HOW IT MADE ME FEEL" 77 "SAD"
                       78 "SEEING CRACK USED ON TV"
                       79 "SELLING OF DRUGS/FINANCIAL" 80 "SEXUALLY"
                       81 "SNEAKY" 82 "SOMEONE HANDED IT TO ME"
                       83 "SPORTING EVENTS" 84 "STRESSED"
                       85 "TALKING ABOUT DRUGS" 86 "THERE"
                       87 "THINKING ABOUT CHILDHOOD ABUSE"
                       88 "THINKING ABOUT ILLNESS" 89 "TRAGEDY IN FAMILY"
                       90 "TRIGGERS" 91 "UNDER PRESSURE"
                       92 "UNEXPECTED CRAVINGS" 93 "VACATION"
                       94 "WANT A REWARD" 95 "WANT TO FEEL GOOD"
                       96 "WHEN RESPONDENT HAS THE MONEY"
                       97 "WHEN DENIED SOMETHING"
                       98 "WHEN FEELING ON TOP OF THE WORLD"
                       99 "WHEN FRIGHTENED" 100 "WHEN I DRINK/SMOKE"
                       101 "WHEN I HAVE DRUGS/RUN UP ON DRUGS HIDDEN"
                       102 "WHEN I HAVENT DONE DRUGS IN AWHILE"
                       103 "WHEN I LEAVE JAIL"
                       104 "WHEN I THINK I CAN RUN THE SHOW"
                       105 "WHEN I WAKE UP"
                       106 "WHEN I WALK INTO A PUBLIC BATHROOM"
                       107 "WHEN IM TIRED" 108 "WHEN PEOPLE DRINK/SMOKE"
                       109 "WHEN SATISFIED" 110 "WHEN THINGS ARE GOING BAD"
                       111 "WHEN THINGS ARE GOING GOOD"
                       112 "WHEN THINKING ABOUT DRUGS"
                       113 "W/BOYFRIEND/GIRLFRIEND/HUSBAND/WIFE"
                       114 "WORK PROBLEMS" ;
label define ME43B1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME43B2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME43B3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL CONFIDENT/SURE"
                       1 "SOMEWHAT CONFIDENT/SURE" 2 "VERY CONFIDENT/SURE" ;
label define ME44      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define ME45      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define ME46      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH"
                       3 "NO TX RECEIVED" ;
label define ME47      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY DIFFICULT" ;
label define ME48      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "VERY POOR" 2 "FAIR" 3 "VERY GOOD" ;
label define ME49      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH"
                       3 "NO TX RECEIVED" ;
label define ME50A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME50B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME50C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME50D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME51      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ME52      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS THAN ONCE A MONTH"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define ME53      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "LESS THAN ONCE A MONTH"
                       3 "AT LEAST ONCE A WEEK" 4 "ALMOST DAILY" ;
label define MF1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF1A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF1B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF1C1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF1C_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF1D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF2B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF2B_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF2C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF3A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF3A_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF3B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF4A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF4A_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF4B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF5A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF5A_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF5B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF6A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF6A_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF6B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF7A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER CONTACT"
                       2 "AT LEAST 1 WEEK AFTER CONTACT" ;
label define MF7A_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF7B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MF10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MF11A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define MF12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MF12A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MF12B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MF13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF15      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF18      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF19      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MF22      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "STRONGLY DISAGREE" 2 "SOMEWHAT DISAGREE"
                       3 "SOMEWHAT AGREE" 4 "STRONGLY AGREE" ;
label define MG1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG2_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG2_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG3_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG4_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG5_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG6A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "1 OR 2 TIMES" 2 "3 TO 5 TIMES" 3 "6 TO 10 TIMES"
                       4 "11 TO 49 TIMES" 5 "50 OR MORE TIMES" ;
label define MG6B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 0 "NEVER"
                       1 "1 OR 2 TIMES" 2 "3 TO 5 TIMES" 3 "6 TO 10 TIMES"
                       4 "11 TO 49 TIMES" 5 "50 OR MORE TIMES" ;
label define MG7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG7A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY SERIOUS" ;
label define MG8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO POLICE OR LEGAL PROBS" 1 "NOT AT ALL SERIOUS"
                       2 "SLIGHTLY SERIOUS" 3 "MODERATELY SERIOUS"
                       4 "CONSIDERABLY SERIOUS" 5 "EXTREMELY SERIOUS" ;
label define MG8A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO POLICE OR LEGAL PROBS" 1 "NOT AT ALL SERIOUS"
                       2 "SLIGHTLY SERIOUS" 3 "MODERATELY SERIOUS"
                       4 "CONSIDERABLY SERIOUS" 5 "EXTREMELY SERIOUS" ;
label define MG8B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO POLICE OR LEGAL PROBS" 1 "NOT AT ALL SERIOUS"
                       2 "SLIGHTLY SERIOUS" 3 "MODERATELY SERIOUS"
                       4 "CONSIDERABLY SERIOUS" 5 "EXTREMELY SERIOUS" ;
label define MG9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MG9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "WORKING AT A LEGITIMATE JOB"
                       2 "HAD A JOB BUT WAS NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "KEEPING HOUSE FOR YOURSELF/FAMILY"
                       5 "GOING TO SCHOOL OR TRAINING"
                       6 "UNABLE TO WORK, DISABLED" 7 "RETIRED" 8 "IN JAIL"
                       9 "INVOLVED IN DRUG RELATED ACTS"
                       10 "INVOLVD IN OTHER ILLEGAL ACTIVITIES"
                       11 "NOT WORKING/NOT INTERESTED IN WORKING" 12 "OTHER" ;
label define MH2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH2B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH2C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MH2D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MH2E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED DURING WEEK"
                       4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FIND PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORK WEEK USUALLY UNDER 35 HOURS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TX PROGRAM"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES"
                       16 "OTHER (SPECIFY)" ;
label define MH2F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH2G      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED DURING WEEK"
                       4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FIND PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY WITH OTHER ACTIVITIES"
                       10 "DID NOT WANT/NEED FULL-TIME WORK"
                       11 "WORK WEEK USUALLY UNDER 35 HOURS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TX PROGRAM"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES"
                       16 "OTHER (SPECIFY)" ;
label define MH3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVE" 7 "TRANSPORTATION EQUIPMENT OPERATIVE"
                       8 "NONFARM LABOR" 9 "PRIVATE HOUSEHOLD WORKER"
                       10 "SERVICE WORKER" 11 "FARMER AND FARM MANAGER"
                       12 "FARM LABORER" 20 "MILITARY SERVICE" 86 "OTHER" ;
label define MH3A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUBLIC ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define MH3B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH3B_SP   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVE" 7 "TRANSPORTATION EQUIPMENT OPERATIVE"
                       8 "NONFARM LABOR" 9 "PRIVATE HOUSEHOLD WORKER"
                       10 "SERVICE WORKER" 11 "FARMER AND FARM MANAGER"
                       12 "FARM LABORER" 20 "MILITARY SERVICE" 86 "OTHER" ;
label define MH4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH4A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH4B1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MH4B2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MH4B3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MH4B4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MH4B5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MH4B6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MH4B7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MH4C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH4D1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MH4D2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MH4D3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MH4D4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MH4D5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MH4D6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MH4D7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MH4D8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MH4D10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define MH4D11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MH5_0     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MH5_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MH5_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MH5_3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MH5_4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MH5_5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MH5_6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MH5_7     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MH5_8     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MH5_9     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MH5_10    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define MH5_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MH5_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define MH5_13    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define MH5_15    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       15 "CIRCLED" ;
label define MH5_16    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       16 "CIRCLED" ;
label define MH6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MH7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "LESS THAN 1 WEEK" ;
label define MH8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MH9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MH9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVE" 7 "TRANSPORTATION EQUIPMENT OPERATIVE"
                       8 "NONFARM LABOR" 9 "PRIVATE HOUSEHOLD WORKER"
                       10 "SERVICE WORKER" 11 "FARMER AND FARM MANAGER"
                       12 "FARM LABORER" 20 "MILITARY SERVICE" 86 "OTHER" ;
label define MH10A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUBLIC ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define MH10B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MH10B_SP  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVE" 7 "TRANSPORTATION EQUIPMENT OPERATIVE"
                       8 "NONFARM LABOR" 9 "PRIVATE HOUSEHOLD WORKER"
                       10 "SERVICE WORKER" 11 "FARMER AND FARM MANAGER"
                       12 "FARM LABORER" 20 "MILITARY SERVICE" 86 "OTHER" ;
label define MH11      -9.00 "LEGITIMATE SKIP" -8.00 "BLANK/MISSING"
                       -7.00 "REFUSAL" -6.00 "MULTIPLE RESPONSE"
                       -5.00 "BAD DATA" -4.00 "DONT KNOW"
                       -3.00 "NOT APPLICABLE" -2.00 "RESPONSE ILLEGIBLE" ;
label define MH11R     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "HOUR"
                       2 "WEEK" 3 "2 WEEKS" 4 "MONTH" 5 "YEAR" 6 "OTHER" ;
label define MH12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MH12A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MH12B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MH13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MH14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ1A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ1B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ2B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ1C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ2C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ1D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ2D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ1E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ2E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ1F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ1F_SP   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "OTHER" ;
label define MJ2F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ2G      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO INCOME" 1 "$ 1 - $ 499" 2 "$ 500 - $ 749"
                       3 "$ 750 - $ 999" 4 "$ 1,000 - $ 1,249"
                       5 "$ 1,250 - $ 1,499" 6 "$ 1,500 - $ 1,749"
                       7 "$ 1,750 - $ 1,999" 8 "$ 2,000 - $ 2,249"
                       9 "$ 2,250 - $ 2,499" 10 "$ 2,500 - $ 2,999"
                       12 "$ 3,000 - $ 3,499" 14 "$ 3,500 - $ 3,999"
                       16 "$ 4,000 - $ 4,499" 18 "$ 4,500 - $ 4,999"
                       20 "$ 5,000 - $ 5,999" 24 "$ 6,000 - $ 7,499"
                       30 "$ 7,500 - $ 9,999" 40 "$10,000 - $12,499"
                       50 "$12,500 - $24,999" 100 "$25,000 OR MORE" ;
label define MJ4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ4A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO INCOME" 1 "$ 1 - $ 499" 2 "$ 500 - $ 749"
                       3 "$ 750 - $ 999" 4 "$ 1,000 - $ 1,249"
                       5 "$ 1,250 - $ 1,499" 6 "$ 1,500 - $ 1,749"
                       7 "$ 1,750 - $ 1,999" 8 "$ 2,000 - $ 2,249"
                       9 "$ 2,250 - $ 2,499" 10 "$ 2,500 - $ 2,999"
                       12 "$ 3,000 - $ 3,499" 14 "$ 3,500 - $ 3,999"
                       16 "$ 4,000 - $ 4,499" 18 "$ 4,500 - $ 4,999"
                       20 "$ 5,000 - $ 5,999" 24 "$ 6,000 - $ 7,499"
                       30 "$ 7,500 - $ 9,999" 40 "$10,000 - $12,499"
                       50 "$12,500 - $24,999" 100 "$25,000 OR MORE" ;
label define MJ6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MJ7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MJ8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define MJ9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MJ9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MJ9B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MJ10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MK1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" ;
label define MK2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MUCH BETTER" 2 "BETTER" 3 "THE SAME" 4 "WORSE"
                       5 "MUCH WORSE" ;
label define MK3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "MUCH BETTER" 2 "BETTER" 3 "THE SAME" 4 "WORSE"
                       5 "MUCH WORSE" ;
label define MK4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MK4A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK4B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK4C1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MK4C2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MK4C3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MK4C4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MK5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK7A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK7B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK7C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK7D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK7E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK7F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK8F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 3 MOS" 2 "3 MOS OR MORE" ;
label define MK9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MK10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MK12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MK13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MK14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK14A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK14B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK14C1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "INH/ISONIAZID/RIMACTANE" 2 "VITAMINS"
                       3 "PILLS & VITAMINS (B1 OR B6)" 4 "PRESCRIBED PILLS"
                       5 "RIFAMATE" 6 "GOT A SHOT" 7 "FORGOT NAME OF PILLS"
                       8 "INH" 9 "ANTIBIOTICS-TB" 10 "TYLENOL PILLS" ;
label define MK14C2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "INH/ISONIAZID/RIMACTANE" 2 "VITAMINS"
                       3 "PILLS & VITAMINS (B1 OR B6)" 4 "PRESCRIBED PILLS"
                       5 "RIFAMATE" 6 "GOT A SHOT" 7 "FORGOT NAME OF PILLS"
                       8 "INH" 9 "ANTIBIOTICS-TB" 10 "TYLENOL PILLS" ;
label define MK14C3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "INH/ISONIAZID/RIMACTANE" 2 "VITAMINS"
                       3 "PILLS & VITAMINS (B1 OR B6)" 4 "PRESCRIBED PILLS"
                       5 "RIFAMATE" 6 "GOT A SHOT" 7 "FORGOT NAME OF PILLS"
                       8 "INH" 9 "ANTIBIOTICS-TB" 10 "TYLENOL PILLS" ;
label define MK15      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MK16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MK16A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MK16B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define MK17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "CONSIDERABLY" 4 "EXTREMELY" ;
label define ML1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD VAGINAL SEX WITH A WOMAN" 1 "NONE"
                       2 "1 WOMAN" 3 "2 TO 4 WOMEN" 4 "5 TO 9 WOMEN"
                       5 "10 TO 20 WOMEN" 6 "21 TO 99 WOMEN"
                       7 "100 OR MORE WOMEN" ;
label define ML1A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "1 WOMAN" 3 "2 TO 4 WOMEN" 4 "5 TO 9 WOMEN"
                       5 "10 TO 20 WOMEN" 6 "21 TO 99 WOMEN"
                       7 "100 OR MORE WOMEN" ;
label define ML2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "1 WOMAN" 3 "2 TO 4 WOMEN" 4 "5 TO 9 WOMEN"
                       5 "10 TO 20 WOMEN" 6 "21 TO 99 WOMEN"
                       7 "100 OR MORE WOMEN" ;
label define ML3A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD SEX WITH A MAN" 1 "NONE" 2 "1 MAN"
                       3 "2 TO 4 MEN" 4 "5 TO 9 MEN" 5 "10 TO 20 MEN"
                       6 "21 TO 99 MEN" 7 "100 OR MORE MEN" ;
label define ML8A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NONE"
                       2 "1 MAN" 3 "2 TO 4 MEN" 4 "5 TO 9 MEN"
                       5 "10 TO 20 MEN" 6 "21 TO 99 MEN" 7 "100 OR MORE MEN" ;
label define ML9A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML12      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML13A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "1 PERSON" 2 "2 TO 4 PEOPLE" 3 "5 OR MORE PEOPLE" ;
label define ML14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD VAGINAL INTERCOURSE W/MAN" 1 "NONE"
                       2 "1 MAN" 3 "2 TO 4 MEN" 4 "5 TO 9 MEN"
                       5 "10 TO 20 MEN" 6 "21 TO 99 MEN" 7 "100 OR MORE MEN" ;
label define ML14A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML15      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD ANAL SEX WITH A MAN" 1 "NONE" 2 "1 MAN"
                       3 "2 TO 4 MEN" 4 "5 TO 9 MEN" 5 "10 TO 20 MEN"
                       6 "21 TO 99 MEN" 7 "100 OR MORE MEN" ;
label define ML15A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEVER HAD ORAL SEX WITH A MAN" 1 "NONE" 2 "1 MAN"
                       3 "2 TO 4 MEN" 4 "5 TO 9 MEN" 5 "10 TO 20 MEN"
                       6 "21 TO 99 MEN" 7 "100 OR MORE MEN" ;
label define ML16A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "NEVER"
                       2 "SOMETIMES" 3 "USUALLY" 4 "EVERY TIME" ;
label define ML17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML18      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML19      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML22      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML22A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "1 MAN"
                       2 "2 TO 4 MEN" 3 "5 OR MORE MEN" ;
label define ML23      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define ML23A1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define ML23A2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define ML23A3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define ML23A4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define ML23B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ML23C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define MM1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM2A1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM2A2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM2A3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM2A4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM2A5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AA     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BA     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CA_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MM3CA_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DA     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHR SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM3B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AB     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BB     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CB_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JANUARY" 2 "FEBRUARY" 3 "MARCH"
                       4 "APRIL" 5 "MAY" 6 "JUNE" 7 "JULY" 8 "AUGUST"
                       9 "SEPTEMBER" 10 "OCTOBER" 11 "NOVEMBER" 12 "DECEMBER" ;
label define MM3CB_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DB     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHR SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM3C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AC     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BC     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CC_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MM3CC_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DC     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHR SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM3D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AD     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BD     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CD_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MM3CD_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DD     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHR SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM3E      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AE     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BE     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CE_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MM3CE_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DE     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHR SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM3F      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM3AF     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3BF     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM3CF_MO  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MM3CF_YR  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" ;
label define MM3DF     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "COMPLETED TX"
                       2 "DISCHARGED BECAUSE OF HOSPITALIZATION"
                       3 "TRANSFERRED TO COMPONENT PROGRAM"
                       4 "TRANSFERRD TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DROPPED/NONCOMPLIANCE"
                       6 "VOLUNTARILY DROPPED OUT/PERSONAL"
                       7 "QUIT/DISSATISFIED WITH PROGRAM" 8 "OTHER" ;
label define MM4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM4A1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM4A2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM4A3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM4A4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM4A5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MM4A6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MM5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM5A1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM5A2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM5A3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM5A4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM5B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM5C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM5D      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "LESS THAN 1 WEEK AFTER DATE"
                       2 "AT LEAST 1 WEEK AFTER DATE" ;
label define MM5D_WK   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM6A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH"
                       94 "NOT APPLICABLE" ;
label define MM6B      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY MUCH"
                       94 "NOT APPLICABLE" ;
label define MM7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM8_1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM8_2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM8_11    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MM8_12    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define MM8_13    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define MM8_21    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define MM8_22    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define MM8_23    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define MM8_28    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define MM8_91    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define MM9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM10      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM10A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM10B0    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "CIRCLED" ;
label define MM10B1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM10B2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM10B3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM10B4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM10B5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       5 "CIRCLED" ;
label define MM10B6    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MM10B7    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       7 "CIRCLED" ;
label define MM10B8    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       8 "CIRCLED" ;
label define MM10B9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MM10B10   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       10 "CIRCLED" ;
label define MM10B11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MM10B12   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define MM10B13   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define MM11      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM12_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM12_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM12_22   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define MM12_23   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define MM12_24   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       24 "CIRCLED" ;
label define MM12_25   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       25 "CIRCLED" ;
label define MM12_26   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       26 "CIRCLED" ;
label define MM12_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define MM13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM14      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM15_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM15_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM15_11   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       11 "CIRCLED" ;
label define MM15_12   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       12 "CIRCLED" ;
label define MM15_13   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       13 "CIRCLED" ;
label define MM15_21   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       21 "CIRCLED" ;
label define MM15_22   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       22 "CIRCLED" ;
label define MM15_23   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       23 "CIRCLED" ;
label define MM15_28   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       28 "CIRCLED" ;
label define MM15_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define MM16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY TROUBLED" ;
label define MM18      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM19_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM19_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM19_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM19_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM19_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define MM20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM22_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM22_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM22_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM22_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM22_91   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       91 "CIRCLED" ;
label define MM23      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM24      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM25_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM25_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM25_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM25_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MM26      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM27      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM28_1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MM28_2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MM28_3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MM28_4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MM28_9    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       9 "CIRCLED" ;
label define MM29      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM30      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM30A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MM30B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "SOMEWHAT" 2 "VERY HELPFUL" ;
label define MM31      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO SERVICES" 1 "REGULAR ADDICTION GROUP"
                       2 "OTHER GROUP COUNSELING" 3 "INDIVIDUAL COUNSELING"
                       4 "12-STEP/SELF-HELP GROUP" 5 "CRISIS COUNSELING"
                       6 "UNSCHEDULED HELP" 7 "TALKS/FILMS/DISCUSSIONS"
                       8 "DRUG COUNSELING" 9 "ALCOHOL COUNSELING"
                       10 "DRUG TESTING" 11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY/RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define MM32      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO SERVICES" 1 "REGULAR ADDICTION GROUP"
                       2 "OTHER GROUP COUNSELING" 3 "INDIVIDUAL COUNSELING"
                       4 "12-STEP/SELF-HELP GROUP" 5 "CRISIS COUNSELING"
                       6 "UNSCHEDULED HELP" 7 "TALKS/FILMS/DISCUSSIONS"
                       8 "DRUG COUNSELING" 9 "ALCOHOL COUNSELING"
                       10 "DRUG TESTING" 11 "PSYCHOLOGICAL/MENTAL HEALTH"
                       12 "FAMILY/RELATIONSHIP COUNSELING" 13 "MEDICATION"
                       14 "MEDICAL" 15 "LEGAL" 16 "EDUCATION/JOB TRAINING"
                       17 "HELP FINDING A JOB" 18 "OTHER JOB ASSISTANCE"
                       19 "FINANCIAL ASSISTANCE" 91 "OTHER" ;
label define MM33      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "A LOT" ;
label define MM33A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LITTLE" 2 "A LOT" ;
label define MM34      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NOT AT ALL" 1 "A LITTLE" 2 "A LOT" ;
label define MM35      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MM35A1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LOT OF ANGER TOWARDS CSD"
                       2 "ABLE TO CONCENTRATE MORE, THINK BETTER"
                       3 "ABLE TO COPE W/DEPRESSION"
                       4 "ABLE TO DEAL W/OTHER PEOPLE/COMMUNICATE/"
                       5 "ANXIETY" 6 "AWARE OF PAIN IVE CAUSED"
                       7 "BAD SELF-ESTEEM" 8 "BAD THOUGHTS" 9 "BEING SELFISH"
                       10 "BETTER BEHAVIOR ABOUT DRUGS" 11 "BETTER LIFESTYLE"
                       12 "BETTER MENTAL HEALTH & PHYSICAL"
                       13 "BETTER QUALITY OF FRIENDS" 14 "CAN GO TO SCHOOL"
                       15 "CARE ABOUT APPEARANCE"
                       16 "CHANGE IN DRINKING HABITS"
                       17 "CHANGED BOYFRIEND/GIRLFRIEND"
                       18 "CHANGES IN MYSELF" 19 "CHANGING RELATIONSHIPS"
                       20 "CONFUSION/UNHAPPY W/THINGS AT HOME" 21 "COUNSELOR"
                       22 "DEAL W/ A PARTNER WHO HAS A JOB" 23 "DEPRESSED"
                       24 "DEPRESSED ABOUT AIDS CONDITION"
                       25 "DESIRE TO STAY OUT OF PRISON BECAUSE OF"
                       26 "DISCOURAGED" 27 "DIVORCE" 28 "DO NOT USE DRUGS"
                       29 "DONT GET EMOTIONALLY UPSET"
                       30 "DONT GO TO THE SAME PLACES"
                       31 "DONT HAVE A RELATIONSHIP"
                       32 "DONT HAVE TO HAVE A MAN/WOMAN"
                       33 "ENJOY PHYSICAL ACTIVITIES, SPORTS/OUTGOI"
                       34 "ENJOY WORKING, DEDICATED JOB/JOB SECURIT"
                       35 "FEAR" 36 "FEEL BETTER" 37 "FEEL WANTED"
                       38 "FINANCIAL SITUATION/PAYING BACK TX" 39 "FORGETFUL"
                       40 "GAINED WEIGHT" 41 "GIVING" 42 "GOING TO SCHOOL"
                       43 "HAPPIER" 44 "HAPPY W/SIMPLE THINGS"
                       45 "HAVE A JOB"
                       46 "HAVE BECOME BETTER PERSON/DEAL W/PROBS"
                       47 "HAVE DREAMS" 48 "HIGHER SELF-ESTEEM, RESPECT"
                       49 "HONEST RELATIONSHIP (1 PARTNER)"
                       50 "HONEST/DOES NOT STEAL/MORE TRUSTWORTHY"
                       51 "I CAN CRY" 52 "I FEEL GRATEFUL"
                       53 "IMPROVEMENT IN FAMILY SETTING/RELATIONSH"
                       54 "INSECURE" 55 "JOB CHANGES" 56 "JUST SO-SO"
                       57 "KEPT USING DRUGS" 58 "LESS ARGUING"
                       59 "LESS DEPRESSED" 60 "LESS EMOTIONAL" 61 "LESS OPEN"
                       62 "LESS PATIENT" 63 "LESS SUSPICIOUS"
                       64 "LESS TALKATIVE" 65 "LESS TRUSTING"
                       66 "LIVING IN A BETTER NEIGHBORHOOD" 67 "LONESOME"
                       68 "LOSS APPETITE" 69 "MARRIED/IN LOVE"
                       70 "MORE MONEY"
                       71 "MORE AWARE OF OWN FEELINGS/CARING/THINKI"
                       72 "MORE FORGIVING" 73 "MORE HELPFUL"
                       74 "MORE INDEPENDENT" 75 "MORE MATURE"
                       76 "MORE MOTIVATED" 77 "MORE PASSION"
                       78 "MORE POSITIVE ATTITUDE/CONFIDENCE"
                       79 "MORE REALISTIC" 80 "MORE RELAXED"
                       81 "MORE RESPONSIBLE" 82 "MORE SECURE"
                       83 "MORE SELF-CONTROL/PATIENT/LESS ANGER"
                       84 "MORE SPIRITUALITY" 85 "MORE STRUCTURE"
                       86 "MORE UNDERSTANDING" 87 "NEED CHANGES"
                       88 "NOT AS STRONG PHYSICALLY" 89 "OPEN-MINDED"
                       90 "PARENTING SKILLS" 91 "PEOPLE ARE AFRAID OF ME"
                       92 "PERSONALITY" 93 "POWERLESS"
                       94 "RECOGNIZING PAST PATTERN"
                       95 "RELATIONSHIP W/FAMILY WORSE" 96 "RESENTMENT"
                       97 "SELF EXPECTANCY/SET HIGHER GOALS"
                       98 "SEXUAL BEHAVIOR" 99 "SLEEP BETTER"
                       100 "STILL HAVE MORE THINGS TO WORK OUT"
                       101 "STOP USING DRUGS"
                       102 "STOPPED DEALING W/OLD FRIENDS" 103 "TEMPER"
                       104 "THE PROGRAM" 105 "THINK LESS ABOUT LUST"
                       106 "THOUGHTS-LIVE DAY TO DAY"
                       107 "TIRED OF BEING A COUCH POTATO"
                       108 "VERY INDEPENDENT" 109 "WANT TO GET HIGH"
                       110 "WEIGHT LOSS" 111 "WORSE TEMPER" ;
label define MM35A2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LOT OF ANGER TOWARDS CSD"
                       2 "ABLE TO CONCENTRATE MORE, THINK BETTER"
                       3 "ABLE TO COPE W/DEPRESSION"
                       4 "ABLE TO DEAL W/OTHER PEOPLE/COMMUNICATE/"
                       5 "ANXIETY" 6 "AWARE OF PAIN IVE CAUSED"
                       7 "BAD SELF-ESTEEM" 8 "BAD THOUGHTS" 9 "BEING SELFISH"
                       10 "BETTER BEHAVIOR ABOUT DRUGS" 11 "BETTER LIFESTYLE"
                       12 "BETTER MENTAL HEALTH & PHYSICAL"
                       13 "BETTER QUALITY OF FRIENDS" 14 "CAN GO TO SCHOOL"
                       15 "CARE ABOUT APPEARANCE"
                       16 "CHANGE IN DRINKING HABITS"
                       17 "CHANGED BOYFRIEND/GIRLFRIEND"
                       18 "CHANGES IN MYSELF" 19 "CHANGING RELATIONSHIPS"
                       20 "CONFUSION/UNHAPPY W/THINGS AT HOME" 21 "COUNSELOR"
                       22 "DEAL W/ A PARTNER WHO HAS A JOB" 23 "DEPRESSED"
                       24 "DEPRESSED ABOUT AIDS CONDITION"
                       25 "DESIRE TO STAY OUT OF PRISON BECAUSE OF"
                       26 "DISCOURAGED" 27 "DIVORCE" 28 "DO NOT USE DRUGS"
                       29 "DONT GET EMOTIONALLY UPSET"
                       30 "DONT GO TO THE SAME PLACES"
                       31 "DONT HAVE A RELATIONSHIP"
                       32 "DONT HAVE TO HAVE A MAN/WOMAN"
                       33 "ENJOY PHYSICAL ACTIVITIES, SPORTS/OUTGOI"
                       34 "ENJOY WORKING, DEDICATED JOB/JOB SECURIT"
                       35 "FEAR" 36 "FEEL BETTER" 37 "FEEL WANTED"
                       38 "FINANCIAL SITUATION/PAYING BACK TX" 39 "FORGETFUL"
                       40 "GAINED WEIGHT" 41 "GIVING" 42 "GOING TO SCHOOL"
                       43 "HAPPIER" 44 "HAPPY W/SIMPLE THINGS"
                       45 "HAVE A JOB"
                       46 "HAVE BECOME BETTER PERSON/DEAL W/PROBS"
                       47 "HAVE DREAMS" 48 "HIGHER SELF-ESTEEM, RESPECT"
                       49 "HONEST RELATIONSHIP (1 PARTNER)"
                       50 "HONEST/DOES NOT STEAL/MORE TRUSTWORTHY"
                       51 "I CAN CRY" 52 "I FEEL GRATEFUL"
                       53 "IMPROVEMENT IN FAMILY SETTING/RELATIONSH"
                       54 "INSECURE" 55 "JOB CHANGES" 56 "JUST SO-SO"
                       57 "KEPT USING DRUGS" 58 "LESS ARGUING"
                       59 "LESS DEPRESSED" 60 "LESS EMOTIONAL" 61 "LESS OPEN"
                       62 "LESS PATIENT" 63 "LESS SUSPICIOUS"
                       64 "LESS TALKATIVE" 65 "LESS TRUSTING"
                       66 "LIVING IN A BETTER NEIGHBORHOOD" 67 "LONESOME"
                       68 "LOSS APPETITE" 69 "MARRIED/IN LOVE"
                       70 "MORE MONEY"
                       71 "MORE AWARE OF OWN FEELINGS/CARING/THINKI"
                       72 "MORE FORGIVING" 73 "MORE HELPFUL"
                       74 "MORE INDEPENDENT" 75 "MORE MATURE"
                       76 "MORE MOTIVATED" 77 "MORE PASSION"
                       78 "MORE POSITIVE ATTITUDE/CONFIDENCE"
                       79 "MORE REALISTIC" 80 "MORE RELAXED"
                       81 "MORE RESPONSIBLE" 82 "MORE SECURE"
                       83 "MORE SELF-CONTROL/PATIENT/LESS ANGER"
                       84 "MORE SPIRITUALITY" 85 "MORE STRUCTURE"
                       86 "MORE UNDERSTANDING" 87 "NEED CHANGES"
                       88 "NOT AS STRONG PHYSICALLY" 89 "OPEN-MINDED"
                       90 "PARENTING SKILLS" 91 "PEOPLE ARE AFRAID OF ME"
                       92 "PERSONALITY" 93 "POWERLESS"
                       94 "RECOGNIZING PAST PATTERN"
                       95 "RELATIONSHIP W/FAMILY WORSE" 96 "RESENTMENT"
                       97 "SELF EXPECTANCY/SET HIGHER GOALS"
                       98 "SEXUAL BEHAVIOR" 99 "SLEEP BETTER"
                       100 "STILL HAVE MORE THINGS TO WORK OUT"
                       101 "STOP USING DRUGS"
                       102 "STOPPED DEALING W/OLD FRIENDS" 103 "TEMPER"
                       104 "THE PROGRAM" 105 "THINK LESS ABOUT LUST"
                       106 "THOUGHTS-LIVE DAY TO DAY"
                       107 "TIRED OF BEING A COUCH POTATO"
                       108 "VERY INDEPENDENT" 109 "WANT TO GET HIGH"
                       110 "WEIGHT LOSS" 111 "WORSE TEMPER" ;
label define MM35A3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LOT OF ANGER TOWARDS CSD"
                       2 "ABLE TO CONCENTRATE MORE, THINK BETTER"
                       3 "ABLE TO COPE W/DEPRESSION"
                       4 "ABLE TO DEAL W/OTHER PEOPLE/COMMUNICATE/"
                       5 "ANXIETY" 6 "AWARE OF PAIN IVE CAUSED"
                       7 "BAD SELF-ESTEEM" 8 "BAD THOUGHTS" 9 "BEING SELFISH"
                       10 "BETTER BEHAVIOR ABOUT DRUGS" 11 "BETTER LIFESTYLE"
                       12 "BETTER MENTAL HEALTH & PHYSICAL"
                       13 "BETTER QUALITY OF FRIENDS" 14 "CAN GO TO SCHOOL"
                       15 "CARE ABOUT APPEARANCE"
                       16 "CHANGE IN DRINKING HABITS"
                       17 "CHANGED BOYFRIEND/GIRLFRIEND"
                       18 "CHANGES IN MYSELF" 19 "CHANGING RELATIONSHIPS"
                       20 "CONFUSION/UNHAPPY W/THINGS AT HOME" 21 "COUNSELOR"
                       22 "DEAL W/ A PARTNER WHO HAS A JOB" 23 "DEPRESSED"
                       24 "DEPRESSED ABOUT AIDS CONDITION"
                       25 "DESIRE TO STAY OUT OF PRISON BECAUSE OF"
                       26 "DISCOURAGED" 27 "DIVORCE" 28 "DO NOT USE DRUGS"
                       29 "DONT GET EMOTIONALLY UPSET"
                       30 "DONT GO TO THE SAME PLACES"
                       31 "DONT HAVE A RELATIONSHIP"
                       32 "DONT HAVE TO HAVE A MAN/WOMAN"
                       33 "ENJOY PHYSICAL ACTIVITIES, SPORTS/OUTGOI"
                       34 "ENJOY WORKING, DEDICATED JOB/JOB SECURIT"
                       35 "FEAR" 36 "FEEL BETTER" 37 "FEEL WANTED"
                       38 "FINANCIAL SITUATION/PAYING BACK TX" 39 "FORGETFUL"
                       40 "GAINED WEIGHT" 41 "GIVING" 42 "GOING TO SCHOOL"
                       43 "HAPPIER" 44 "HAPPY W/SIMPLE THINGS"
                       45 "HAVE A JOB"
                       46 "HAVE BECOME BETTER PERSON/DEAL W/PROBS"
                       47 "HAVE DREAMS" 48 "HIGHER SELF-ESTEEM, RESPECT"
                       49 "HONEST RELATIONSHIP (1 PARTNER)"
                       50 "HONEST/DOES NOT STEAL/MORE TRUSTWORTHY"
                       51 "I CAN CRY" 52 "I FEEL GRATEFUL"
                       53 "IMPROVEMENT IN FAMILY SETTING/RELATIONSH"
                       54 "INSECURE" 55 "JOB CHANGES" 56 "JUST SO-SO"
                       57 "KEPT USING DRUGS" 58 "LESS ARGUING"
                       59 "LESS DEPRESSED" 60 "LESS EMOTIONAL" 61 "LESS OPEN"
                       62 "LESS PATIENT" 63 "LESS SUSPICIOUS"
                       64 "LESS TALKATIVE" 65 "LESS TRUSTING"
                       66 "LIVING IN A BETTER NEIGHBORHOOD" 67 "LONESOME"
                       68 "LOSS APPETITE" 69 "MARRIED/IN LOVE"
                       70 "MORE MONEY"
                       71 "MORE AWARE OF OWN FEELINGS/CARING/THINKI"
                       72 "MORE FORGIVING" 73 "MORE HELPFUL"
                       74 "MORE INDEPENDENT" 75 "MORE MATURE"
                       76 "MORE MOTIVATED" 77 "MORE PASSION"
                       78 "MORE POSITIVE ATTITUDE/CONFIDENCE"
                       79 "MORE REALISTIC" 80 "MORE RELAXED"
                       81 "MORE RESPONSIBLE" 82 "MORE SECURE"
                       83 "MORE SELF-CONTROL/PATIENT/LESS ANGER"
                       84 "MORE SPIRITUALITY" 85 "MORE STRUCTURE"
                       86 "MORE UNDERSTANDING" 87 "NEED CHANGES"
                       88 "NOT AS STRONG PHYSICALLY" 89 "OPEN-MINDED"
                       90 "PARENTING SKILLS" 91 "PEOPLE ARE AFRAID OF ME"
                       92 "PERSONALITY" 93 "POWERLESS"
                       94 "RECOGNIZING PAST PATTERN"
                       95 "RELATIONSHIP W/FAMILY WORSE" 96 "RESENTMENT"
                       97 "SELF EXPECTANCY/SET HIGHER GOALS"
                       98 "SEXUAL BEHAVIOR" 99 "SLEEP BETTER"
                       100 "STILL HAVE MORE THINGS TO WORK OUT"
                       101 "STOP USING DRUGS"
                       102 "STOPPED DEALING W/OLD FRIENDS" 103 "TEMPER"
                       104 "THE PROGRAM" 105 "THINK LESS ABOUT LUST"
                       106 "THOUGHTS-LIVE DAY TO DAY"
                       107 "TIRED OF BEING A COUCH POTATO"
                       108 "VERY INDEPENDENT" 109 "WANT TO GET HIGH"
                       110 "WEIGHT LOSS" 111 "WORSE TEMPER" ;
label define MM35A4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LOT OF ANGER TOWARDS CSD"
                       2 "ABLE TO CONCENTRATE MORE, THINK BETTER"
                       3 "ABLE TO COPE W/DEPRESSION"
                       4 "ABLE TO DEAL W/OTHER PEOPLE/COMMUNICATE/"
                       5 "ANXIETY" 6 "AWARE OF PAIN IVE CAUSED"
                       7 "BAD SELF-ESTEEM" 8 "BAD THOUGHTS" 9 "BEING SELFISH"
                       10 "BETTER BEHAVIOR ABOUT DRUGS" 11 "BETTER LIFESTYLE"
                       12 "BETTER MENTAL HEALTH & PHYSICAL"
                       13 "BETTER QUALITY OF FRIENDS" 14 "CAN GO TO SCHOOL"
                       15 "CARE ABOUT APPEARANCE"
                       16 "CHANGE IN DRINKING HABITS"
                       17 "CHANGED BOYFRIEND/GIRLFRIEND"
                       18 "CHANGES IN MYSELF" 19 "CHANGING RELATIONSHIPS"
                       20 "CONFUSION/UNHAPPY W/THINGS AT HOME" 21 "COUNSELOR"
                       22 "DEAL W/ A PARTNER WHO HAS A JOB" 23 "DEPRESSED"
                       24 "DEPRESSED ABOUT AIDS CONDITION"
                       25 "DESIRE TO STAY OUT OF PRISON BECAUSE OF"
                       26 "DISCOURAGED" 27 "DIVORCE" 28 "DO NOT USE DRUGS"
                       29 "DONT GET EMOTIONALLY UPSET"
                       30 "DONT GO TO THE SAME PLACES"
                       31 "DONT HAVE A RELATIONSHIP"
                       32 "DONT HAVE TO HAVE A MAN/WOMAN"
                       33 "ENJOY PHYSICAL ACTIVITIES, SPORTS/OUTGOI"
                       34 "ENJOY WORKING, DEDICATED JOB/JOB SECURIT"
                       35 "FEAR" 36 "FEEL BETTER" 37 "FEEL WANTED"
                       38 "FINANCIAL SITUATION/PAYING BACK TX" 39 "FORGETFUL"
                       40 "GAINED WEIGHT" 41 "GIVING" 42 "GOING TO SCHOOL"
                       43 "HAPPIER" 44 "HAPPY W/SIMPLE THINGS"
                       45 "HAVE A JOB"
                       46 "HAVE BECOME BETTER PERSON/DEAL W/PROBS"
                       47 "HAVE DREAMS" 48 "HIGHER SELF-ESTEEM, RESPECT"
                       49 "HONEST RELATIONSHIP (1 PARTNER)"
                       50 "HONEST/DOES NOT STEAL/MORE TRUSTWORTHY"
                       51 "I CAN CRY" 52 "I FEEL GRATEFUL"
                       53 "IMPROVEMENT IN FAMILY SETTING/RELATIONSH"
                       54 "INSECURE" 55 "JOB CHANGES" 56 "JUST SO-SO"
                       57 "KEPT USING DRUGS" 58 "LESS ARGUING"
                       59 "LESS DEPRESSED" 60 "LESS EMOTIONAL" 61 "LESS OPEN"
                       62 "LESS PATIENT" 63 "LESS SUSPICIOUS"
                       64 "LESS TALKATIVE" 65 "LESS TRUSTING"
                       66 "LIVING IN A BETTER NEIGHBORHOOD" 67 "LONESOME"
                       68 "LOSS APPETITE" 69 "MARRIED/IN LOVE"
                       70 "MORE MONEY"
                       71 "MORE AWARE OF OWN FEELINGS/CARING/THINKI"
                       72 "MORE FORGIVING" 73 "MORE HELPFUL"
                       74 "MORE INDEPENDENT" 75 "MORE MATURE"
                       76 "MORE MOTIVATED" 77 "MORE PASSION"
                       78 "MORE POSITIVE ATTITUDE/CONFIDENCE"
                       79 "MORE REALISTIC" 80 "MORE RELAXED"
                       81 "MORE RESPONSIBLE" 82 "MORE SECURE"
                       83 "MORE SELF-CONTROL/PATIENT/LESS ANGER"
                       84 "MORE SPIRITUALITY" 85 "MORE STRUCTURE"
                       86 "MORE UNDERSTANDING" 87 "NEED CHANGES"
                       88 "NOT AS STRONG PHYSICALLY" 89 "OPEN-MINDED"
                       90 "PARENTING SKILLS" 91 "PEOPLE ARE AFRAID OF ME"
                       92 "PERSONALITY" 93 "POWERLESS"
                       94 "RECOGNIZING PAST PATTERN"
                       95 "RELATIONSHIP W/FAMILY WORSE" 96 "RESENTMENT"
                       97 "SELF EXPECTANCY/SET HIGHER GOALS"
                       98 "SEXUAL BEHAVIOR" 99 "SLEEP BETTER"
                       100 "STILL HAVE MORE THINGS TO WORK OUT"
                       101 "STOP USING DRUGS"
                       102 "STOPPED DEALING W/OLD FRIENDS" 103 "TEMPER"
                       104 "THE PROGRAM" 105 "THINK LESS ABOUT LUST"
                       106 "THOUGHTS-LIVE DAY TO DAY"
                       107 "TIRED OF BEING A COUCH POTATO"
                       108 "VERY INDEPENDENT" 109 "WANT TO GET HIGH"
                       110 "WEIGHT LOSS" 111 "WORSE TEMPER" ;
label define MM35A5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "A LOT OF ANGER TOWARDS CSD"
                       2 "ABLE TO CONCENTRATE MORE, THINK BETTER"
                       3 "ABLE TO COPE W/DEPRESSION"
                       4 "ABLE TO DEAL W/OTHER PEOPLE/COMMUNICATE/"
                       5 "ANXIETY" 6 "AWARE OF PAIN IVE CAUSED"
                       7 "BAD SELF-ESTEEM" 8 "BAD THOUGHTS" 9 "BEING SELFISH"
                       10 "BETTER BEHAVIOR ABOUT DRUGS" 11 "BETTER LIFESTYLE"
                       12 "BETTER MENTAL HEALTH & PHYSICAL"
                       13 "BETTER QUALITY OF FRIENDS" 14 "CAN GO TO SCHOOL"
                       15 "CARE ABOUT APPEARANCE"
                       16 "CHANGE IN DRINKING HABITS"
                       17 "CHANGED BOYFRIEND/GIRLFRIEND"
                       18 "CHANGES IN MYSELF" 19 "CHANGING RELATIONSHIPS"
                       20 "CONFUSION/UNHAPPY W/THINGS AT HOME" 21 "COUNSELOR"
                       22 "DEAL W/ A PARTNER WHO HAS A JOB" 23 "DEPRESSED"
                       24 "DEPRESSED ABOUT AIDS CONDITION"
                       25 "DESIRE TO STAY OUT OF PRISON BECAUSE OF"
                       26 "DISCOURAGED" 27 "DIVORCE" 28 "DO NOT USE DRUGS"
                       29 "DONT GET EMOTIONALLY UPSET"
                       30 "DONT GO TO THE SAME PLACES"
                       31 "DONT HAVE A RELATIONSHIP"
                       32 "DONT HAVE TO HAVE A MAN/WOMAN"
                       33 "ENJOY PHYSICAL ACTIVITIES, SPORTS/OUTGOI"
                       34 "ENJOY WORKING, DEDICATED JOB/JOB SECURIT"
                       35 "FEAR" 36 "FEEL BETTER" 37 "FEEL WANTED"
                       38 "FINANCIAL SITUATION/PAYING BACK TX" 39 "FORGETFUL"
                       40 "GAINED WEIGHT" 41 "GIVING" 42 "GOING TO SCHOOL"
                       43 "HAPPIER" 44 "HAPPY W/SIMPLE THINGS"
                       45 "HAVE A JOB"
                       46 "HAVE BECOME BETTER PERSON/DEAL W/PROBS"
                       47 "HAVE DREAMS" 48 "HIGHER SELF-ESTEEM, RESPECT"
                       49 "HONEST RELATIONSHIP (1 PARTNER)"
                       50 "HONEST/DOES NOT STEAL/MORE TRUSTWORTHY"
                       51 "I CAN CRY" 52 "I FEEL GRATEFUL"
                       53 "IMPROVEMENT IN FAMILY SETTING/RELATIONSH"
                       54 "INSECURE" 55 "JOB CHANGES" 56 "JUST SO-SO"
                       57 "KEPT USING DRUGS" 58 "LESS ARGUING"
                       59 "LESS DEPRESSED" 60 "LESS EMOTIONAL" 61 "LESS OPEN"
                       62 "LESS PATIENT" 63 "LESS SUSPICIOUS"
                       64 "LESS TALKATIVE" 65 "LESS TRUSTING"
                       66 "LIVING IN A BETTER NEIGHBORHOOD" 67 "LONESOME"
                       68 "LOSS APPETITE" 69 "MARRIED/IN LOVE"
                       70 "MORE MONEY"
                       71 "MORE AWARE OF OWN FEELINGS/CARING/THINKI"
                       72 "MORE FORGIVING" 73 "MORE HELPFUL"
                       74 "MORE INDEPENDENT" 75 "MORE MATURE"
                       76 "MORE MOTIVATED" 77 "MORE PASSION"
                       78 "MORE POSITIVE ATTITUDE/CONFIDENCE"
                       79 "MORE REALISTIC" 80 "MORE RELAXED"
                       81 "MORE RESPONSIBLE" 82 "MORE SECURE"
                       83 "MORE SELF-CONTROL/PATIENT/LESS ANGER"
                       84 "MORE SPIRITUALITY" 85 "MORE STRUCTURE"
                       86 "MORE UNDERSTANDING" 87 "NEED CHANGES"
                       88 "NOT AS STRONG PHYSICALLY" 89 "OPEN-MINDED"
                       90 "PARENTING SKILLS" 91 "PEOPLE ARE AFRAID OF ME"
                       92 "PERSONALITY" 93 "POWERLESS"
                       94 "RECOGNIZING PAST PATTERN"
                       95 "RELATIONSHIP W/FAMILY WORSE" 96 "RESENTMENT"
                       97 "SELF EXPECTANCY/SET HIGHER GOALS"
                       98 "SEXUAL BEHAVIOR" 99 "SLEEP BETTER"
                       100 "STILL HAVE MORE THINGS TO WORK OUT"
                       101 "STOP USING DRUGS"
                       102 "STOPPED DEALING W/OLD FRIENDS" 103 "TEMPER"
                       104 "THE PROGRAM" 105 "THINK LESS ABOUT LUST"
                       106 "THOUGHTS-LIVE DAY TO DAY"
                       107 "TIRED OF BEING A COUCH POTATO"
                       108 "VERY INDEPENDENT" 109 "WANT TO GET HIGH"
                       110 "WEIGHT LOSS" 111 "WORSE TEMPER" ;
label define MM35B1    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define MM35B2    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define MM35B3    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define MM35B4    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define MM35B5    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "SELF"
                       2 "COUNSELOR OR CASE MANAGER" 3 "ANOTHER STAFF MEMBER"
                       4 "ANOTHER CLIENT/RESIDENT/PATIENT"
                       5 "THE PROGRAM OVERALL"
                       6 "SOMETHING/SOMEONE OUTSIDE PROGRAM" 7 "OTHER" ;
label define MMD_MO    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MMT_HH    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MMT_MM    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MMAMPM    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;
label define MN1       -8 "BLANK/MISSING" -7 "REFUSAL" -6 "MULTIPLE RESPONSE"
                       -5 "BAD DATA" -4 "DONT KNOW" -3 "NOT APPLICABLE"
                       -2 "RESPONSE ILLEGIBLE" 1 "YES" 2 "NO" ;
label define MN2       -8 "BLANK/MISSING" -7 "REFUSAL" -6 "MULTIPLE RESPONSE"
                       -5 "BAD DATA" -4 "DONT KNOW" -3 "NOT APPLICABLE"
                       -2 "RESPONSE ILLEGIBLE" 1 "YES" 2 "NO" ;
label define MN2A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MN3_1_1   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MN3_1_2   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define MN3_4_1   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MN3_4_2   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "MILD"
                       2 "MODERATE" 3 "EXTREME" ;
label define MN4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MN4A1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CIRCLED" ;
label define MN4A2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       2 "CIRCLED" ;
label define MN4A3     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       3 "CIRCLED" ;
label define MN4A4     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MN4A5     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       4 "CIRCLED" ;
label define MN4A6     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       6 "CIRCLED" ;
label define MN5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "EAGER"
                       2 "RECEPTIVE" 3 "NO REACTION" 4 "RELUCTANT"
                       5 "REFUSED" 6 "NOT DISCUSSED" ;
label define MN6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MN6A1     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MN6A2     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MP1       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MP2       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP3       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP4       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP5       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP6       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP7       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP8       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP9       -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP10A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP10B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP11A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP11B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP11C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP12A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CANT DO" ;
label define MP12B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CANT DO" ;
label define MP12C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CANT DO" ;
label define MP12D     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CANT DO" ;
label define MP12E     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR" 7 "SAYS CANT DO" ;
label define MP13      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NO ERROR" 1 "1 ERROR" 2 "2 ERRORS" 3 "3 ERRORS"
                       4 "4 ERRORS" 5 "5 ERRORS" ;
label define MP14A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP14B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP14C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" ;
label define MP15A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP15B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP16      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP17      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP"
                       7 "CANT READ ENGLISH" ;
label define MP18A     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP18B     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP18C     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define MP19      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO" 6 "HANDICAP"
                       7 "CANT WRITE (ENGLISH)" ;
label define MP20      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       1 "CORRECT" 5 "ERROR/CANT DO" 6 "HANDICAP" ;
label define MP21      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "YES"
                       2 "NO" ;
label define MPDM      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define MPTH      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MPTM      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MODALITY  1 "Long-term Residential" 2 "Short-term Inpatient"
                       3 "Outpatient Methadone" 4 "Outpatient Drug Free" ;
label define MD6C      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define ME26      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define MG1A      -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define URINE     0 "Not in urinalysis subsample"
                       1 "In urinalysis subsample" ;
label define FTWORK    0 "None" 1 "1 to 13 weeks" 2 "14 to 39 weeks"
                       3 "40 to 52 weeks" ;
label define MSTAT     1 "Legally Married" 2 "Separated" 3 "Divorced"
                       4 "Widowed" 5 "Living as Married" 6 "Never married" ;
label define SEX       1 "Male" 2 "Female" ;
label define AGE       55 "55+" ;
label define AGEGRP    1 "Under 18" 2 "18 - 20" 3 "21 - 25" 4 "26 - 30"
                       5 "31 - 35" 6 "36 - 44" 7 "Over 44" ;
label define RACE      1 "Caucasian/White" 2 "Afro-American/Black"
                       3 "Hispanic" 4 "Other" ;
label define EDLEV     0 "None" 1 "Grade School or less" 2 "High School"
                       3 "High School Degree" 4 "Some College"
                       5 "Jr College/Associate degree" 6 "College Degree"
                       7 "Advanced Degree" ;
label define RACESEX   1 "Caucasian/White Male" 2 "Afro-American/Black Male"
                       3 "Hispanic Male" 4 "Other Male"
                       5 "Caucasian/White Female"
                       6 "Afro-American/Black Female" 7 "Hispanic Female"
                       8 "Other Female" ;
label define HVY_ALC   0 "Not a heavy user" 1 "Heavy alcohol user" ;
label define DRUGPAT   1 "Heroin/Narcotic/no coke"
                       2 "Coke w/heroin or narcotics" 3 "Coke only"
                       4 "Coke and Alcohol" 5 "Coke plus other drugs"
                       6 "Marijuana and/or alcohol" 7 "Residual" ;
label define ALCWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define MRJWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define COCWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define CRKWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define HERWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define NARWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define SEDWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define AMPWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define HALWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define INHWK     0 "Less than weekly use" 1 "Weekly or more use" ;
label define TOPS_PAT  1 "Heroin" 2 "Heroin and Opioids" 3 "Other Opioids"
                       4 "Multiple Non-opioid" 5 "Single Non-opioid"
                       6 "Marijuana and/or alcohol" 7 "Residual/Minimal Use" ;
label define CJ_STAT   0 "No legal status" 1 "In Jail/detention"
                       2 "Probation" 3 "Parole" 4 "Case Pending" ;
label define MAJSRC    0 "No income" 1 "Legal work" 2 "Public assistance"
                       3 "Social Security" 4 "Family,friends"
                       5 "Illegal sources" 6 "Other sources" ;
label define REFER     0 "Self (only if no other primary or"
                       1 "Medical Service" 10 "Community Agency"
                       20 "Legal system" 30 "Probation & parole"
                       40 "Prison system" 50 "Family or friends" 60 "School"
                       70 "Employer" 80 "Veteran" 90 "Other" ;
label define PDRUGFRQ  -9 "No primary drug denoted" 0 "No use"
                       1 "Less than once a month" 2 "1 to 3 times a month"
                       3 "1 to 2 times a week" 4 "3 to 4 times a week"
                       5 "5 to 6 times a week" 6 "Daily or almost every day"
                       7 "2 to 3 times a day" 8 "4 or more times a day" ;
label define HERHX     0 "Never Used" 1 "Used 1 - 5 times only"
                       2 "Used sporatically or monthly"
                       3 "Used more than 4 wks on weekly basis"
                       4 "Used more than 4 weeks on daily basis" ;
label define COCHX     0 "Never Used" 1 "Used 1 - 5 times only"
                       2 "Used sporatically or monthly"
                       3 "Used more than 4 weeks on wkly basis"
                       4 "Used more than 4 weeks on daily basis" ;
label define RESTRICT  0 "No weeks restricted" 1 "1 to 4 weeks restricted"
                       2 "5 to 13 weeks restricted"
                       3 "14 to 26 weeks restricted"
                       4 "27 to 39 weeks restricted"
                       5 "40 to 50 weeks restricted"
                       6 "51 to 52 weeks restricted" ;
label define DRGTXAGE  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define HLTHINS   0 "None" 1 "Private /other" 2 "Public" ;
label define MGV_SIA   0 "None" 1 "1 to 2 acts" 2 "3 to 5 acts"
                       3 "6 to 10 acts" 4 "11 to 25 acts" 5 "Over 25 acts" ;
label define MB1A_DTM  -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "STILL IN TX" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define CTOS      0 "Not a CTOS case" 1 "Client also in CTOS" ;
label define OP_TYP    1 "Hospital based program" 2 "Community based program"
                       3 "Therapeutic Community (TC)" ;
label define MAV_SEX   1 "Male" 2 "Female" ;
label define MAV_MST   1 "Married" 2 "Legally separated" 3 "Divorced"
                       4 "Widowed" 5 "Living as married" 6 "Never Married" ;
label define MAV_AGEG  1 "18 - 20" 2 "21 - 25" 3 "26 - 30" 4 "31 - 35"
                       5 "36 - 40" 6 "41 - 65" ;
label define MAV_RACE  1 "White/Caucasian" 2 "Black/African American"
                       3 "Of Hispanic/Spanish origin or descent" 4 "Other" ;
label define MAV_CJS   0 "No Criminal Justice Status" 1 "In Jail / detention"
                       2 "Probation" 3 "Parole" 4 "Case pending/other status" ;
label define MBV_TERM  0 "Still in TX (DATOS followup only)" 1 "Completed TX"
                       2 "Involuntarily discharged" 3 "Transferred"
                       4 "Quit - Personal reasons"
                       5 "Quit - Financial reasons"
                       6 "Quit - dissatisfied with program" 7 "Other reason" ;
label define MCV_HALC  0 "Not a heavy user" 1 "Heavy alcohol user" ;
label define MCV_SUIC  0 "No suicidal thoughts or attempts"
                       1 "Suicidal thoughts" 2 "Suicidal attempts" ;
label define MCV_PDT   0 "No drug TX prior to index treatme"
                       1 "1 prior drug TX admission" 2 "2-3 prior admissions"
                       3 "4 or more prior admissions" ;
label define MCV_CJS   0 "No Criminal Justice Status" 1 "In Jail / detention"
                       2 "Probation" 3 "Parole" 4 "Case pending/other status" ;
label define MCV_DR    0 "None" 1 "1 to 2 arrests" 2 "3 or more arrests" ;
label define MCV_DWI   0 "None" 1 "1 to 2 arrests" 2 "3 or more arrests" ;
label define MCV_NDR   0 "None" 1 "1 to 2 arrests" 2 "3 or more arrests" ;
label define MCV_EMP   1 "Working" 2 "Looking for work/Going to school"
                       3 "Keeping house" 4 "Disabled/retired"
                       5 "In jail,residential TX,other inst"
                       6 "Drug related or illegal activities"
                       7 "Other,multiple" ;
label define MCV_ALC   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_HAL   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_MRJ   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_COC   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_CRK   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_HER   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_NAR   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_SED   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_AMP   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MCV_SUI   0 "No suicidal thoughts or attempts"
                       1 "Suicidal thoughts" 2 "Suicidal attempts" ;
label define MDV_EDYR  0 "None" 1 "Grade school (1-8 grades)"
                       2 "Some High school (9-11)" 3 "Completed 12 grades"
                       4 "13 to 16 years" 5 "17 or more" ;
label define MDV_DEG   0 "None" 1 "Certificate or license"
                       2 "High school degree or GED"
                       3 "Jr College or AA degree" 4 "Bachelors degree"
                       5 "Advanced degree" ;
label define MDV_ENRL  0 "None" 1 "Other,job corps,spec ed" 2 "Middle school"
                       3 "Adult Basic education"
                       4 "Technical or trade school" 5 "GED / High school"
                       6 "Jr college" 7 "College or graduate school" ;
label define MEV_HALC  0 "No heavy use" 1 "Heavy alcohol use" ;
label define MEV_INJ   0 "No injection drug use" 1 "Injection drug use" ;
label define MEV_ALC   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_MRJ   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_HAL   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_COC   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_CRK   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_HER   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_NAR   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_SED   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_AMP   0 "No use" 1 "Monthly" 2 "Weekly" 3 "Daily" ;
label define MEV_PAT   1 "Heroin/Narcotic/no coke"
                       2 "Coke w/heroin or narcotics" 3 "Coke only"
                       4 "Coke and Alcohol" 5 "Coke plus other drugs"
                       6 "Marijuana and/or alcohol" 7 "Residual" ;
label define MEV_PDRG  0 "None" 10 "Alcohol" 20 "Marijuana"
                       30 "Hallucinogens" 40 "Cocaine" 41 "Crack"
                       50 "Heroin/speedball" 60 "Narcotics or opiates"
                       70 "Sedative/Barbiturates" 80 "Amphetamines"
                       90 "Other drugs" ;
label define MFV_SUIC  0 "No suicidal thoughts or attempts"
                       1 "Suicidal thoughts" 2 "Suicidal attempts" ;
label define MGV_DR    0 "No arrests" 1 "1 to 2 arrests"
                       2 "3 or more arrests" ;
label define MGV_DWI   0 "No arrests" 1 "1 to 2 arrests"
                       2 "3 or more arrests" ;
label define MGV_NDR   0 "No arrests" 1 "1 to 2 arrests"
                       2 "3 or more arrests" ;
label define MGV_JAIL  0 "None" 1 "1 to 10 days" 2 "11 to 30 days"
                       3 "31 to 91 days" 4 "92 to 182 days"
                       5 "183 days or more" ;
label define MHV_FTWK  0 "None" 1 "1 to 13 weeks" 2 "14 to 39 weeks"
                       3 "40 to 52 weeks" ;
label define MHV_EMP   1 "Working" 2 "Looking for work/Going to school"
                       3 "Keeping house" 4 "Disabled/retired"
                       5 "In jail,residential tx,other institution"
                       6 "Drug related or illegal activities"
                       7 "Other,multiple" ;
label define MJV_SRC   0 "No income" 1 "Legal work" 2 "Public assistance"
                       3 "Social Security" 4 "Family, friends"
                       5 "Illegal sources" 6 "Other sources" ;
label define MLV_RSK1  0 "No" 1 "Yes" ;
label define MLV_RSK2  0 "No" 1 "Yes" ;
label define MLV_RSK3  0 "No" 1 "Yes" ;
label define MLV_RSK4  0 "No" 1 "Yes" ;
label define MLV_RSK6  0 "No" 1 "Yes" ;
label define MLV_SEXB  0 "Not active" 1 "1 partner, always use condoms"
                       2 "1-partner, some/never use condoms"
                       3 "2-4 partners, always use condoms"
                       4 "2-4 partners, some/never use condoms"
                       5 "5 or more partners, always use condoms"
                       6 "5 or more partners, sometimes/never use" ;
label define MLV_RSK5  0 "No" 1 "Yes" ;
label define MMV_DT    0 "None" 1 "1 admission" 2 "2 to 3 admissions"
                       3 "4 or more admissions" ;
label define PDRUG     -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO PRIMARY DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define FAVDRUG   -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define MPAMPM    -9 "LEGITIMATE SKIP" -8 "BLANK/MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DONT KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" 1 "AM"
                       2 "PM" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace MFIRE = . if (MFIRE <= -1 )
replace MTOLE = . if (MTOLE <= -1 )
replace MTS_HH = . if (MTS_HH <= -1 )
replace MTS_MM = . if (MTS_MM <= -1 )
replace MTSAMPM = . if (MTSAMPM <= -1 )
replace MA1 = . if (MA1 <= -1 )
replace MA2 = . if (MA2 <= -1 )
replace MA5 = . if (MA5 <= -1 )
replace MA6 = . if (MA6 <= -1 )
replace MA7 = . if (MA7 <= -1 )
replace MA8 = . if (MA8 <= -1 )
replace MA9_0 = . if (MA9_0 <= -1 )
replace MA9_1 = . if (MA9_1 <= -1 )
replace MA9A_1 = . if (MA9A_1 <= -1 )
replace MA9B_1 = . if (MA9B_1 <= -1 )
replace MA9C_1 = . if (MA9C_1 <= -1 )
replace MA9D_1 = . if (MA9D_1 <= -1 )
replace MA9_2 = . if (MA9_2 <= -1 )
replace MA9A_2 = . if (MA9A_2 <= -1 )
replace MA9B_2 = . if (MA9B_2 <= -1 )
replace MA9C_2 = . if (MA9C_2 <= -1 )
replace MA9D_2 = . if (MA9D_2 <= -1 )
replace MA9_3 = . if (MA9_3 <= -1 )
replace MA9A_3 = . if (MA9A_3 <= -1 )
replace MA9B_3 = . if (MA9B_3 <= -1 )
replace MA9C_3 = . if (MA9C_3 <= -1 )
replace MA9D_3 = . if (MA9D_3 <= -1 )
replace MA9_4 = . if (MA9_4 <= -1 )
replace MA9A_4 = . if (MA9A_4 <= -1 )
replace MA9B_4 = . if (MA9B_4 <= -1 )
replace MA9C_4 = . if (MA9C_4 <= -1 )
replace MA9D_4 = . if (MA9D_4 <= -1 )
replace MA9_5 = . if (MA9_5 <= -1 )
replace MA9A_5 = . if (MA9A_5 <= -1 )
replace MA9B_5 = . if (MA9B_5 <= -1 )
replace MA9C_5 = . if (MA9C_5 <= -1 )
replace MA9D_5 = . if (MA9D_5 <= -1 )
replace MA10 = . if (MA10 <= -1 )
replace MA11A = . if (MA11A <= -1 )
replace MA11B = . if (MA11B <= -1 )
replace MA11C = . if (MA11C <= -1 )
replace MA12A = . if (MA12A <= -1 )
replace MA12B = . if (MA12B <= -1 )
replace MA12C = . if (MA12C <= -1 )
replace MA12D = . if (MA12D <= -1 )
replace MA12E = . if (MA12E <= -1 )
replace MA12F = . if (MA12F <= -1 )
replace MA12G = . if (MA12G <= -1 )
replace MA13 = . if (MA13 <= -1 )
replace MA14_0 = . if (MA14_0 <= -1 )
replace MA14_1 = . if (MA14_1 <= -1 )
replace MA14_2 = . if (MA14_2 <= -1 )
replace MA14_3 = . if (MA14_3 <= -1 )
replace MA14_4 = . if (MA14_4 <= -1 )
replace MA14_5 = . if (MA14_5 <= -1 )
replace MA14_6 = . if (MA14_6 <= -1 )
replace MA14_7 = . if (MA14_7 <= -1 )
replace MA14_8 = . if (MA14_8 <= -1 )
replace MA14_9 = . if (MA14_9 <= -1 )
replace MA15 = . if (MA15 <= -1 )
replace MA15A = . if (MA15A <= -1 )
replace MB1 = . if (MB1 <= -1 )
replace MB1A_MO = . if (MB1A_MO <= -1 )
replace MB1A_YR = . if (MB1A_YR <= -1 )
replace MB2 = . if (MB2 <= -1 )
replace MB2A = . if (MB2A <= -1 )
replace MB2B = . if (MB2B <= -1 )
replace MB2C = . if (MB2C <= -1 )
replace MB3 = . if (MB3 <= -1 )
replace MB3A = . if (MB3A <= -1 )
replace MB3B = . if (MB3B <= -1 )
replace MB3C_1 = . if (MB3C_1 <= -1 )
replace MB3C_2 = . if (MB3C_2 <= -1 )
replace MB3C_3 = . if (MB3C_3 <= -1 )
replace MB3C_4 = . if (MB3C_4 <= -1 )
replace MB3C_5 = . if (MB3C_5 <= -1 )
replace MB3C_6 = . if (MB3C_6 <= -1 )
replace MB3C_7 = . if (MB3C_7 <= -1 )
replace MB3C_8 = . if (MB3C_8 <= -1 )
replace MB4_0 = . if (MB4_0 <= -1 )
replace MB4_1 = . if (MB4_1 <= -1 )
replace MB4_2 = . if (MB4_2 <= -1 )
replace MB4_3 = . if (MB4_3 <= -1 )
replace MB4_4 = . if (MB4_4 <= -1 )
replace MB4_5 = . if (MB4_5 <= -1 )
replace MB4_6 = . if (MB4_6 <= -1 )
replace MB4_7 = . if (MB4_7 <= -1 )
replace MB4_8 = . if (MB4_8 <= -1 )
replace MB4_9 = . if (MB4_9 <= -1 )
replace MB5 = . if (MB5 <= -1 )
replace MB6 = . if (MB6 <= -1 )
replace MB7 = . if (MB7 <= -1 )
replace MB8 = . if (MB8 <= -1 )
replace MB9 = . if (MB9 <= -1 )
replace MB10 = . if (MB10 <= -1 )
replace MB11 = . if (MB11 <= -1 )
replace MB11A_1 = . if (MB11A_1 <= -1 )
replace MB11A_2 = . if (MB11A_2 <= -1 )
replace MB11A_3 = . if (MB11A_3 <= -1 )
replace MB11A_4 = . if (MB11A_4 <= -1 )
replace MB11A_5 = . if (MB11A_5 <= -1 )
replace MB11A_6 = . if (MB11A_6 <= -1 )
replace MB11A_7 = . if (MB11A_7 <= -1 )
replace MB11A_8 = . if (MB11A_8 <= -1 )
replace MB12 = . if (MB12 <= -1 )
replace MB13 = . if (MB13 <= -1 )
replace MB14B_10 = . if (MB14B_10 <= -1 )
replace MB14B_20 = . if (MB14B_20 <= -1 )
replace MB14B_30 = . if (MB14B_30 <= -1 )
replace MB14B_40 = . if (MB14B_40 <= -1 )
replace MB14B_41 = . if (MB14B_41 <= -1 )
replace MB14B_42 = . if (MB14B_42 <= -1 )
replace MB14B_50 = . if (MB14B_50 <= -1 )
replace MB14B_60 = . if (MB14B_60 <= -1 )
replace MB14B_70 = . if (MB14B_70 <= -1 )
replace MB14B_80 = . if (MB14B_80 <= -1 )
replace MB14B_90 = . if (MB14B_90 <= -1 )
replace MB15 = . if (MB15 <= -1 )
replace MB16 = . if (MB16 <= -1 )
replace MB17 = . if (MB17 <= -1 )
replace MB18 = . if (MB18 <= -1 )
replace MB18A = . if (MB18A <= -1 )
replace MB19 = . if (MB19 <= -1 )
replace MB19A = . if (MB19A <= -1 )
replace MB19B = . if (MB19B <= -1 )
replace MB20 = . if (MB20 <= -1 )
replace MB21 = . if (MB21 <= -1 )
replace MB22 = . if (MB22 <= -1 )
replace MB23 = . if (MB23 <= -1 )
replace MB23_1 = . if (MB23_1 <= -1 )
replace MB24 = . if (MB24 <= -1 )
replace MB25 = . if (MB25 <= -1 )
replace MB26 = . if (MB26 <= -1 )
replace MB26A = . if (MB26A <= -1 )
replace MC1 = . if (MC1 <= -1 )
replace MC2_0 = . if (MC2_0 <= -1 )
replace MC2_1 = . if (MC2_1 <= -1 )
replace MC2_2 = . if (MC2_2 <= -1 )
replace MC2_3 = . if (MC2_3 <= -1 )
replace MC2_4 = . if (MC2_4 <= -1 )
replace MC2_5 = . if (MC2_5 <= -1 )
replace MC2_6 = . if (MC2_6 <= -1 )
replace MC2_7 = . if (MC2_7 <= -1 )
replace MC2_8 = . if (MC2_8 <= -1 )
replace MC2_9 = . if (MC2_9 <= -1 )
replace MC3 = . if (MC3 <= -1 )
replace MC4 = . if (MC4 <= -1 )
replace MC4_1 = . if (MC4_1 <= -1 )
replace MC5 = . if (MC5 <= -1 )
replace MC6 = . if (MC6 <= -1 )
replace MC6A = . if (MC6A <= -1 )
replace MC7 = . if (MC7 <= -1 )
replace MC8 = . if (MC8 <= -1 )
replace MC9_20 = . if (MC9_20 <= -1 )
replace MC9_30 = . if (MC9_30 <= -1 )
replace MC9_40 = . if (MC9_40 <= -1 )
replace MC9_41 = . if (MC9_41 <= -1 )
replace MC9_42 = . if (MC9_42 <= -1 )
replace MC9_50 = . if (MC9_50 <= -1 )
replace MC9_60 = . if (MC9_60 <= -1 )
replace MC9_70 = . if (MC9_70 <= -1 )
replace MC9_80 = . if (MC9_80 <= -1 )
replace MC9_90 = . if (MC9_90 <= -1 )
replace MC10 = . if (MC10 <= -1 )
replace MC11 = . if (MC11 <= -1 )
replace MC12 = . if (MC12 <= -1 )
replace MC13 = . if (MC13 <= -1 )
replace MC14A = . if (MC14A <= -1 )
replace MC14AA = . if (MC14AA <= -1 )
replace MC14BA = . if (MC14BA <= -1 )
replace MC14B = . if (MC14B <= -1 )
replace MC14AB = . if (MC14AB <= -1 )
replace MC14BB = . if (MC14BB <= -1 )
replace MC14C = . if (MC14C <= -1 )
replace MC14AC = . if (MC14AC <= -1 )
replace MC14BC = . if (MC14BC <= -1 )
replace MC14D = . if (MC14D <= -1 )
replace MC14AD = . if (MC14AD <= -1 )
replace MC14BD = . if (MC14BD <= -1 )
replace MC14E = . if (MC14E <= -1 )
replace MC14AE = . if (MC14AE <= -1 )
replace MC14BE = . if (MC14BE <= -1 )
replace MC14F = . if (MC14F <= -1 )
replace MC14AF = . if (MC14AF <= -1 )
replace MC14BF = . if (MC14BF <= -1 )
replace MC15_1 = . if (MC15_1 <= -1 )
replace MC16_1 = . if (MC16_1 <= -1 )
replace MC17_1 = . if (MC17_1 <= -1 )
replace MC15_2 = . if (MC15_2 <= -1 )
replace MC16_2 = . if (MC16_2 <= -1 )
replace MC17_2 = . if (MC17_2 <= -1 )
replace MC15_3 = . if (MC15_3 <= -1 )
replace MC16_3 = . if (MC16_3 <= -1 )
replace MC17_3 = . if (MC17_3 <= -1 )
replace MC15_4 = . if (MC15_4 <= -1 )
replace MC16_4 = . if (MC16_4 <= -1 )
replace MC17_4 = . if (MC17_4 <= -1 )
replace MC15_5 = . if (MC15_5 <= -1 )
replace MC16_5 = . if (MC16_5 <= -1 )
replace MC17_5 = . if (MC17_5 <= -1 )
replace MC15_6 = . if (MC15_6 <= -1 )
replace MC16_6 = . if (MC16_6 <= -1 )
replace MC17_6 = . if (MC17_6 <= -1 )
replace MC15_7 = . if (MC15_7 <= -1 )
replace MC16_7 = . if (MC16_7 <= -1 )
replace MC17_7 = . if (MC17_7 <= -1 )
replace MC15_8 = . if (MC15_8 <= -1 )
replace MC16_8 = . if (MC16_8 <= -1 )
replace MC17_8 = . if (MC17_8 <= -1 )
replace MC15_9 = . if (MC15_9 <= -1 )
replace MC16_9 = . if (MC16_9 <= -1 )
replace MC17_9 = . if (MC17_9 <= -1 )
replace MC15_10 = . if (MC15_10 <= -1 )
replace MC16_10 = . if (MC16_10 <= -1 )
replace MC17_10 = . if (MC17_10 <= -1 )
replace MC15_11 = . if (MC15_11 <= -1 )
replace MC16_11 = . if (MC16_11 <= -1 )
replace MC17_11 = . if (MC17_11 <= -1 )
replace MC15_12 = . if (MC15_12 <= -1 )
replace MC16_12 = . if (MC16_12 <= -1 )
replace MC17_12 = . if (MC17_12 <= -1 )
replace MC18 = . if (MC18 <= -1 )
replace MC19 = . if (MC19 <= -1 )
replace MC20 = . if (MC20 <= -1 )
replace MC21 = . if (MC21 <= -1 )
replace MC22 = . if (MC22 <= -1 )
replace MC22A = . if (MC22A <= -1 )
replace MD1 = . if (MD1 <= -1 )
replace MD1A = . if (MD1A <= -1 )
replace MD2 = . if (MD2 <= -1 )
replace MD2A = . if (MD2A <= -1 )
replace MD3_0 = . if (MD3_0 <= -1 )
replace MD3_1 = . if (MD3_1 <= -1 )
replace MD3_2 = . if (MD3_2 <= -1 )
replace MD3_3 = . if (MD3_3 <= -1 )
replace MD4 = . if (MD4 <= -1 )
replace MD4A_1 = . if (MD4A_1 <= -1 )
replace MD4A_2 = . if (MD4A_2 <= -1 )
replace MD4A_3 = . if (MD4A_3 <= -1 )
replace MD4A_4 = . if (MD4A_4 <= -1 )
replace MD4A_5 = . if (MD4A_5 <= -1 )
replace MD4A_6 = . if (MD4A_6 <= -1 )
replace MD4A_7 = . if (MD4A_7 <= -1 )
replace MD4A_8 = . if (MD4A_8 <= -1 )
replace MD4A_11 = . if (MD4A_11 <= -1 )
replace MD5 = . if (MD5 <= -1 )
replace MD6 = . if (MD6 <= -1 )
replace MD6A = . if (MD6A <= -1 )
replace MD6B = . if (MD6B <= -1 )
replace MD6D = . if (MD6D <= -1 )
replace MD7 = . if (MD7 <= -1 )
replace ME1 = . if (ME1 <= -1 )
replace ME2 = . if (ME2 <= -1 )
replace ME3 = . if (ME3 <= -1 )
replace ME4 = . if (ME4 <= -1 )
replace ME5 = . if (ME5 <= -1 )
replace ME6 = . if (ME6 <= -1 )
replace ME7 = . if (ME7 <= -1 )
replace ME8 = . if (ME8 <= -1 )
replace ME9 = . if (ME9 <= -1 )
replace ME10 = . if (ME10 <= -1 )
replace ME11 = . if (ME11 <= -1 )
replace ME12 = . if (ME12 <= -1 )
replace ME13 = . if (ME13 <= -1 )
replace ME14 = . if (ME14 <= -1 )
replace ME14A = . if (ME14A <= -1 )
replace ME15_0 = . if (ME15_0 <= -1 )
replace ME15_1 = . if (ME15_1 <= -1 )
replace ME15_2 = . if (ME15_2 <= -1 )
replace ME15_3 = . if (ME15_3 <= -1 )
replace ME16_20 = . if (ME16_20 <= -1 )
replace ME17_20 = . if (ME17_20 <= -1 )
replace ME18_20 = . if (ME18_20 <= -1 )
replace ME19_20 = . if (ME19_20 <= -1 )
replace ME20_20 = . if (ME20_20 <= -1 )
replace ME21_20 = . if (ME21_20 <= -1 )
replace ME16_30 = . if (ME16_30 <= -1 )
replace ME17_30 = . if (ME17_30 <= -1 )
replace ME18_30 = . if (ME18_30 <= -1 )
replace ME19_30 = . if (ME19_30 <= -1 )
replace ME20_30 = . if (ME20_30 <= -1 )
replace ME21_30 = . if (ME21_30 <= -1 )
replace ME16_31 = . if (ME16_31 <= -1 )
replace ME20_31 = . if (ME20_31 <= -1 )
replace ME21_31 = . if (ME21_31 <= -1 )
replace ME16_32 = . if (ME16_32 <= -1 )
replace ME20_32 = . if (ME20_32 <= -1 )
replace ME21_32 = . if (ME21_32 <= -1 )
replace ME16_40 = . if (ME16_40 <= -1 )
replace ME17_40 = . if (ME17_40 <= -1 )
replace ME18_40 = . if (ME18_40 <= -1 )
replace ME19_40 = . if (ME19_40 <= -1 )
replace ME20_40 = . if (ME20_40 <= -1 )
replace ME21_40 = . if (ME21_40 <= -1 )
replace ME16_41 = . if (ME16_41 <= -1 )
replace ME20_41 = . if (ME20_41 <= -1 )
replace ME21_41 = . if (ME21_41 <= -1 )
replace ME16_42 = . if (ME16_42 <= -1 )
replace ME20_42 = . if (ME20_42 <= -1 )
replace ME21_42 = . if (ME21_42 <= -1 )
replace ME16_50 = . if (ME16_50 <= -1 )
replace ME17_50 = . if (ME17_50 <= -1 )
replace ME18_50 = . if (ME18_50 <= -1 )
replace ME19_50 = . if (ME19_50 <= -1 )
replace ME20_50 = . if (ME20_50 <= -1 )
replace ME21_50 = . if (ME21_50 <= -1 )
replace ME16_51 = . if (ME16_51 <= -1 )
replace ME20_51 = . if (ME20_51 <= -1 )
replace ME21_51 = . if (ME21_51 <= -1 )
replace ME16_60 = . if (ME16_60 <= -1 )
replace ME17_60 = . if (ME17_60 <= -1 )
replace ME18_60 = . if (ME18_60 <= -1 )
replace ME19_60 = . if (ME19_60 <= -1 )
replace ME20_60 = . if (ME20_60 <= -1 )
replace ME21_60 = . if (ME21_60 <= -1 )
replace ME16_61 = . if (ME16_61 <= -1 )
replace ME20_61 = . if (ME20_61 <= -1 )
replace ME21_61 = . if (ME21_61 <= -1 )
replace ME16_62 = . if (ME16_62 <= -1 )
replace ME20_62 = . if (ME20_62 <= -1 )
replace ME21_62 = . if (ME21_62 <= -1 )
replace ME16_70 = . if (ME16_70 <= -1 )
replace ME17_70 = . if (ME17_70 <= -1 )
replace ME18_70 = . if (ME18_70 <= -1 )
replace ME19_70 = . if (ME19_70 <= -1 )
replace ME20_70 = . if (ME20_70 <= -1 )
replace ME21_70 = . if (ME21_70 <= -1 )
replace ME16_71 = . if (ME16_71 <= -1 )
replace ME16_72 = . if (ME16_72 <= -1 )
replace ME16_73 = . if (ME16_73 <= -1 )
replace ME16_74 = . if (ME16_74 <= -1 )
replace ME16_75 = . if (ME16_75 <= -1 )
replace ME16_80 = . if (ME16_80 <= -1 )
replace ME17_80 = . if (ME17_80 <= -1 )
replace ME18_80 = . if (ME18_80 <= -1 )
replace ME19_80 = . if (ME19_80 <= -1 )
replace ME20_80 = . if (ME20_80 <= -1 )
replace ME21_80 = . if (ME21_80 <= -1 )
replace ME16_81 = . if (ME16_81 <= -1 )
replace ME20_81 = . if (ME20_81 <= -1 )
replace ME21_81 = . if (ME21_81 <= -1 )
replace ME16_90 = . if (ME16_90 <= -1 )
replace ME17_90 = . if (ME17_90 <= -1 )
replace ME18_90 = . if (ME18_90 <= -1 )
replace ME19_90 = . if (ME19_90 <= -1 )
replace ME20_90 = . if (ME20_90 <= -1 )
replace ME21_90 = . if (ME21_90 <= -1 )
replace ME16_91 = . if (ME16_91 <= -1 )
replace ME20_91 = . if (ME20_91 <= -1 )
replace ME21_91 = . if (ME21_91 <= -1 )
replace ME16_92 = . if (ME16_92 <= -1 )
replace ME20_92 = . if (ME20_92 <= -1 )
replace ME21_92 = . if (ME21_92 <= -1 )
replace ME22_1 = . if (ME22_1 <= -1 )
replace ME22_2 = . if (ME22_2 <= -1 )
replace ME22_3 = . if (ME22_3 <= -1 )
replace ME22_4 = . if (ME22_4 <= -1 )
replace ME23 = . if (ME23 <= -1 )
replace ME24 = . if (ME24 <= -1 )
replace ME25 = . if (ME25 <= -1 )
replace ME27 = . if (ME27 <= -1 )
replace ME27A1 = . if (ME27A1 <= -1 )
replace ME27A2 = . if (ME27A2 <= -1 )
replace ME27A3 = . if (ME27A3 <= -1 )
replace ME28 = . if (ME28 <= -1 )
replace ME29 = . if (ME29 <= -1 )
replace ME29A = . if (ME29A <= -1 )
replace ME30 = . if (ME30 <= -1 )
replace ME30A_1 = . if (ME30A_1 <= -1 )
replace ME30A_2 = . if (ME30A_2 <= -1 )
replace ME30A_3 = . if (ME30A_3 <= -1 )
replace ME30A_4 = . if (ME30A_4 <= -1 )
replace ME30A_5 = . if (ME30A_5 <= -1 )
replace ME30A_6 = . if (ME30A_6 <= -1 )
replace ME31 = . if (ME31 <= -1 )
replace ME31A = . if (ME31A <= -1 )
replace ME31B = . if (ME31B <= -1 )
replace ME32A = . if (ME32A <= -1 )
replace ME32B = . if (ME32B <= -1 )
replace ME32C = . if (ME32C <= -1 )
replace ME32D = . if (ME32D <= -1 )
replace ME32E = . if (ME32E <= -1 )
replace ME32F = . if (ME32F <= -1 )
replace ME33A = . if (ME33A <= -1 )
replace ME33B = . if (ME33B <= -1 )
replace ME33C = . if (ME33C <= -1 )
replace ME33D = . if (ME33D <= -1 )
replace ME33E = . if (ME33E <= -1 )
replace ME33F = . if (ME33F <= -1 )
replace ME33G = . if (ME33G <= -1 )
replace ME34 = . if (ME34 <= -1 )
replace ME35 = . if (ME35 <= -1 )
replace ME36 = . if (ME36 <= -1 )
replace ME37 = . if (ME37 <= -1 )
replace ME38 = . if (ME38 <= -1 )
replace ME39 = . if (ME39 <= -1 )
replace ME40 = . if (ME40 <= -1 )
replace ME41 = . if (ME41 <= -1 )
replace ME41A1 = . if (ME41A1 <= -1 )
replace ME41A2 = . if (ME41A2 <= -1 )
replace ME41A3 = . if (ME41A3 <= -1 )
replace ME42A = . if (ME42A <= -1 )
replace ME42B = . if (ME42B <= -1 )
replace ME42C = . if (ME42C <= -1 )
replace ME42D = . if (ME42D <= -1 )
replace ME42E = . if (ME42E <= -1 )
replace ME42F = . if (ME42F <= -1 )
replace ME42G = . if (ME42G <= -1 )
replace ME42H = . if (ME42H <= -1 )
replace ME42I = . if (ME42I <= -1 )
replace ME42J = . if (ME42J <= -1 )
replace ME42K = . if (ME42K <= -1 )
replace ME42L = . if (ME42L <= -1 )
replace ME42M = . if (ME42M <= -1 )
replace ME42N = . if (ME42N <= -1 )
replace ME42O = . if (ME42O <= -1 )
replace ME42P = . if (ME42P <= -1 )
replace ME42Q = . if (ME42Q <= -1 )
replace ME42R = . if (ME42R <= -1 )
replace ME42S = . if (ME42S <= -1 )
replace ME42T = . if (ME42T <= -1 )
replace ME43 = . if (ME43 <= -1 )
replace ME43A1 = . if (ME43A1 <= -1 )
replace ME43A2 = . if (ME43A2 <= -1 )
replace ME43A3 = . if (ME43A3 <= -1 )
replace ME43B1 = . if (ME43B1 <= -1 )
replace ME43B2 = . if (ME43B2 <= -1 )
replace ME43B3 = . if (ME43B3 <= -1 )
replace ME44 = . if (ME44 <= -1 )
replace ME45 = . if (ME45 <= -1 )
replace ME46 = . if (ME46 <= -1 )
replace ME47 = . if (ME47 <= -1 )
replace ME48 = . if (ME48 <= -1 )
replace ME49 = . if (ME49 <= -1 )
replace ME50A = . if (ME50A <= -1 )
replace ME50B = . if (ME50B <= -1 )
replace ME50C = . if (ME50C <= -1 )
replace ME50D = . if (ME50D <= -1 )
replace ME51 = . if (ME51 <= -1 )
replace ME52 = . if (ME52 <= -1 )
replace ME53 = . if (ME53 <= -1 )
replace MF1 = . if (MF1 <= -1 )
replace MF1A = . if (MF1A <= -1 )
replace MF1B = . if (MF1B <= -1 )
replace MF1C1 = . if (MF1C1 <= -1 )
replace MF1C_WK = . if (MF1C_WK <= -1 )
replace MF1D = . if (MF1D <= -1 )
replace MF2 = . if (MF2 <= -1 )
replace MF2A = . if (MF2A <= -1 )
replace MF2B = . if (MF2B <= -1 )
replace MF2B_WK = . if (MF2B_WK <= -1 )
replace MF2C = . if (MF2C <= -1 )
replace MF3 = . if (MF3 <= -1 )
replace MF3A = . if (MF3A <= -1 )
replace MF3A_WK = . if (MF3A_WK <= -1 )
replace MF3B = . if (MF3B <= -1 )
replace MF4 = . if (MF4 <= -1 )
replace MF4A = . if (MF4A <= -1 )
replace MF4A_WK = . if (MF4A_WK <= -1 )
replace MF4B = . if (MF4B <= -1 )
replace MF5 = . if (MF5 <= -1 )
replace MF5A = . if (MF5A <= -1 )
replace MF5A_WK = . if (MF5A_WK <= -1 )
replace MF5B = . if (MF5B <= -1 )
replace MF6 = . if (MF6 <= -1 )
replace MF6A = . if (MF6A <= -1 )
replace MF6A_WK = . if (MF6A_WK <= -1 )
replace MF6B = . if (MF6B <= -1 )
replace MF7 = . if (MF7 <= -1 )
replace MF7A = . if (MF7A <= -1 )
replace MF7A_WK = . if (MF7A_WK <= -1 )
replace MF7B = . if (MF7B <= -1 )
replace MF8 = . if (MF8 <= -1 )
replace MF9 = . if (MF9 <= -1 )
replace MF9A = . if (MF9A <= -1 )
replace MF10 = . if (MF10 <= -1 )
replace MF11 = . if (MF11 <= -1 )
replace MF11A = . if (MF11A <= -1 )
replace MF12 = . if (MF12 <= -1 )
replace MF12A = . if (MF12A <= -1 )
replace MF12B = . if (MF12B <= -1 )
replace MF13 = . if (MF13 <= -1 )
replace MF14 = . if (MF14 <= -1 )
replace MF15 = . if (MF15 <= -1 )
replace MF16 = . if (MF16 <= -1 )
replace MF17 = . if (MF17 <= -1 )
replace MF18 = . if (MF18 <= -1 )
replace MF19 = . if (MF19 <= -1 )
replace MF20 = . if (MF20 <= -1 )
replace MF21 = . if (MF21 <= -1 )
replace MF22 = . if (MF22 <= -1 )
replace MG1 = . if (MG1 <= -1 )
replace MG2_1 = . if (MG2_1 <= -1 )
replace MG3_1 = . if (MG3_1 <= -1 )
replace MG4_1 = . if (MG4_1 <= -1 )
replace MG5_1 = . if (MG5_1 <= -1 )
replace MG2_2 = . if (MG2_2 <= -1 )
replace MG3_2 = . if (MG3_2 <= -1 )
replace MG4_2 = . if (MG4_2 <= -1 )
replace MG5_2 = . if (MG5_2 <= -1 )
replace MG2_3 = . if (MG2_3 <= -1 )
replace MG3_3 = . if (MG3_3 <= -1 )
replace MG4_3 = . if (MG4_3 <= -1 )
replace MG5_3 = . if (MG5_3 <= -1 )
replace MG2_4 = . if (MG2_4 <= -1 )
replace MG3_4 = . if (MG3_4 <= -1 )
replace MG4_4 = . if (MG4_4 <= -1 )
replace MG5_4 = . if (MG5_4 <= -1 )
replace MG2_5 = . if (MG2_5 <= -1 )
replace MG3_5 = . if (MG3_5 <= -1 )
replace MG4_5 = . if (MG4_5 <= -1 )
replace MG5_5 = . if (MG5_5 <= -1 )
replace MG2_6 = . if (MG2_6 <= -1 )
replace MG3_6 = . if (MG3_6 <= -1 )
replace MG4_6 = . if (MG4_6 <= -1 )
replace MG5_6 = . if (MG5_6 <= -1 )
replace MG2_7 = . if (MG2_7 <= -1 )
replace MG3_7 = . if (MG3_7 <= -1 )
replace MG4_7 = . if (MG4_7 <= -1 )
replace MG5_7 = . if (MG5_7 <= -1 )
replace MG2_8 = . if (MG2_8 <= -1 )
replace MG3_8 = . if (MG3_8 <= -1 )
replace MG4_8 = . if (MG4_8 <= -1 )
replace MG5_8 = . if (MG5_8 <= -1 )
replace MG2_9 = . if (MG2_9 <= -1 )
replace MG3_9 = . if (MG3_9 <= -1 )
replace MG4_9 = . if (MG4_9 <= -1 )
replace MG5_9 = . if (MG5_9 <= -1 )
replace MG2_10 = . if (MG2_10 <= -1 )
replace MG3_10 = . if (MG3_10 <= -1 )
replace MG4_10 = . if (MG4_10 <= -1 )
replace MG5_10 = . if (MG5_10 <= -1 )
replace MG2_11 = . if (MG2_11 <= -1 )
replace MG3_11 = . if (MG3_11 <= -1 )
replace MG4_11 = . if (MG4_11 <= -1 )
replace MG5_11 = . if (MG5_11 <= -1 )
replace MG2_12 = . if (MG2_12 <= -1 )
replace MG3_12 = . if (MG3_12 <= -1 )
replace MG4_12 = . if (MG4_12 <= -1 )
replace MG5_12 = . if (MG5_12 <= -1 )
replace MG6 = . if (MG6 <= -1 )
replace MG6A = . if (MG6A <= -1 )
replace MG6B = . if (MG6B <= -1 )
replace MG7 = . if (MG7 <= -1 )
replace MG7A = . if (MG7A <= -1 )
replace MG8 = . if (MG8 <= -1 )
replace MG8A = . if (MG8A <= -1 )
replace MG8B = . if (MG8B <= -1 )
replace MG9 = . if (MG9 <= -1 )
replace MG9A = . if (MG9A <= -1 )
replace MH1 = . if (MH1 <= -1 )
replace MH2 = . if (MH2 <= -1 )
replace MH2A = . if (MH2A <= -1 )
replace MH2B = . if (MH2B <= -1 )
replace MH2C = . if (MH2C <= -1 )
replace MH2D = . if (MH2D <= -1 )
replace MH2E = . if (MH2E <= -1 )
replace MH2F = . if (MH2F <= -1 )
replace MH2G = . if (MH2G <= -1 )
replace MH3 = . if (MH3 <= -1 )
replace MH3A = . if (MH3A <= -1 )
replace MH3B = . if (MH3B <= -1 )
replace MH3B_SP = . if (MH3B_SP <= -1 )
replace MH4 = . if (MH4 <= -1 )
replace MH4A = . if (MH4A <= -1 )
replace MH4B1 = . if (MH4B1 <= -1 )
replace MH4B2 = . if (MH4B2 <= -1 )
replace MH4B3 = . if (MH4B3 <= -1 )
replace MH4B4 = . if (MH4B4 <= -1 )
replace MH4B5 = . if (MH4B5 <= -1 )
replace MH4B6 = . if (MH4B6 <= -1 )
replace MH4B7 = . if (MH4B7 <= -1 )
replace MH4C = . if (MH4C <= -1 )
replace MH4D1 = . if (MH4D1 <= -1 )
replace MH4D2 = . if (MH4D2 <= -1 )
replace MH4D3 = . if (MH4D3 <= -1 )
replace MH4D4 = . if (MH4D4 <= -1 )
replace MH4D5 = . if (MH4D5 <= -1 )
replace MH4D6 = . if (MH4D6 <= -1 )
replace MH4D7 = . if (MH4D7 <= -1 )
replace MH4D8 = . if (MH4D8 <= -1 )
replace MH4D10 = . if (MH4D10 <= -1 )
replace MH4D11 = . if (MH4D11 <= -1 )
replace MH5_0 = . if (MH5_0 <= -1 )
replace MH5_1 = . if (MH5_1 <= -1 )
replace MH5_2 = . if (MH5_2 <= -1 )
replace MH5_3 = . if (MH5_3 <= -1 )
replace MH5_4 = . if (MH5_4 <= -1 )
replace MH5_5 = . if (MH5_5 <= -1 )
replace MH5_6 = . if (MH5_6 <= -1 )
replace MH5_7 = . if (MH5_7 <= -1 )
replace MH5_8 = . if (MH5_8 <= -1 )
replace MH5_9 = . if (MH5_9 <= -1 )
replace MH5_10 = . if (MH5_10 <= -1 )
replace MH5_11 = . if (MH5_11 <= -1 )
replace MH5_12 = . if (MH5_12 <= -1 )
replace MH5_13 = . if (MH5_13 <= -1 )
replace MH5_15 = . if (MH5_15 <= -1 )
replace MH5_16 = . if (MH5_16 <= -1 )
replace MH6 = . if (MH6 <= -1 )
replace MH7 = . if (MH7 <= -1 )
replace MH8 = . if (MH8 <= -1 )
replace MH9 = . if (MH9 <= -1 )
replace MH9A = . if (MH9A <= -1 )
replace MH10 = . if (MH10 <= -1 )
replace MH10A = . if (MH10A <= -1 )
replace MH10B = . if (MH10B <= -1 )
replace MH10B_SP = . if (MH10B_SP <= -1 )
replace MH11 = . if (MH11 <= -1.00 )
replace MH11R = . if (MH11R <= -1 )
replace MH12 = . if (MH12 <= -1 )
replace MH12A = . if (MH12A <= -1 )
replace MH12B = . if (MH12B <= -1 )
replace MH13 = . if (MH13 <= -1 )
replace MH14 = . if (MH14 <= -1 )
replace MJ1A = . if (MJ1A <= -1 )
replace MJ2A = . if (MJ2A <= -1 )
replace MJ1B = . if (MJ1B <= -1 )
replace MJ2B = . if (MJ2B <= -1 )
replace MJ1C = . if (MJ1C <= -1 )
replace MJ2C = . if (MJ2C <= -1 )
replace MJ1D = . if (MJ1D <= -1 )
replace MJ2D = . if (MJ2D <= -1 )
replace MJ1E = . if (MJ1E <= -1 )
replace MJ2E = . if (MJ2E <= -1 )
replace MJ1F = . if (MJ1F <= -1 )
replace MJ1F_SP = . if (MJ1F_SP <= -1 )
replace MJ2F = . if (MJ2F <= -1 )
replace MJ2G = . if (MJ2G <= -1 )
replace MJ3 = . if (MJ3 <= -1 )
replace MJ4 = . if (MJ4 <= -1 )
replace MJ4A = . if (MJ4A <= -1 )
replace MJ5 = . if (MJ5 <= -1 )
replace MJ6 = . if (MJ6 <= -1 )
replace MJ7 = . if (MJ7 <= -1 )
replace MJ8 = . if (MJ8 <= -1 )
replace MJ9 = . if (MJ9 <= -1 )
replace MJ9A = . if (MJ9A <= -1 )
replace MJ9B = . if (MJ9B <= -1 )
replace MJ10 = . if (MJ10 <= -1 )
replace MK1 = . if (MK1 <= -1 )
replace MK2 = . if (MK2 <= -1 )
replace MK3 = . if (MK3 <= -1 )
replace MK4 = . if (MK4 <= -1 )
replace MK4A = . if (MK4A <= -1 )
replace MK4B = . if (MK4B <= -1 )
replace MK4C1 = . if (MK4C1 <= -1 )
replace MK4C2 = . if (MK4C2 <= -1 )
replace MK4C3 = . if (MK4C3 <= -1 )
replace MK4C4 = . if (MK4C4 <= -1 )
replace MK5 = . if (MK5 <= -1 )
replace MK6 = . if (MK6 <= -1 )
replace MK7A = . if (MK7A <= -1 )
replace MK8A = . if (MK8A <= -1 )
replace MK7B = . if (MK7B <= -1 )
replace MK8B = . if (MK8B <= -1 )
replace MK7C = . if (MK7C <= -1 )
replace MK8C = . if (MK8C <= -1 )
replace MK7D = . if (MK7D <= -1 )
replace MK8D = . if (MK8D <= -1 )
replace MK7E = . if (MK7E <= -1 )
replace MK8E = . if (MK8E <= -1 )
replace MK7F = . if (MK7F <= -1 )
replace MK8F = . if (MK8F <= -1 )
replace MK9 = . if (MK9 <= -1 )
replace MK9A = . if (MK9A <= -1 )
replace MK10 = . if (MK10 <= -1 )
replace MK11 = . if (MK11 <= -1 )
replace MK12 = . if (MK12 <= -1 )
replace MK13 = . if (MK13 <= -1 )
replace MK14 = . if (MK14 <= -1 )
replace MK14A = . if (MK14A <= -1 )
replace MK14B = . if (MK14B <= -1 )
replace MK14C1 = . if (MK14C1 <= -1 )
replace MK14C2 = . if (MK14C2 <= -1 )
replace MK14C3 = . if (MK14C3 <= -1 )
replace MK15 = . if (MK15 <= -1 )
replace MK16 = . if (MK16 <= -1 )
replace MK16A = . if (MK16A <= -1 )
replace MK16B = . if (MK16B <= -1 )
replace MK17 = . if (MK17 <= -1 )
replace ML1 = . if (ML1 <= -1 )
replace ML1A = . if (ML1A <= -1 )
replace ML2 = . if (ML2 <= -1 )
replace ML2A = . if (ML2A <= -1 )
replace ML3 = . if (ML3 <= -1 )
replace ML3A = . if (ML3A <= -1 )
replace ML4 = . if (ML4 <= -1 )
replace ML5 = . if (ML5 <= -1 )
replace ML6 = . if (ML6 <= -1 )
replace ML7 = . if (ML7 <= -1 )
replace ML8 = . if (ML8 <= -1 )
replace ML8A = . if (ML8A <= -1 )
replace ML9 = . if (ML9 <= -1 )
replace ML9A = . if (ML9A <= -1 )
replace ML10 = . if (ML10 <= -1 )
replace ML11 = . if (ML11 <= -1 )
replace ML12 = . if (ML12 <= -1 )
replace ML13 = . if (ML13 <= -1 )
replace ML13A = . if (ML13A <= -1 )
replace ML14 = . if (ML14 <= -1 )
replace ML14A = . if (ML14A <= -1 )
replace ML15 = . if (ML15 <= -1 )
replace ML15A = . if (ML15A <= -1 )
replace ML16 = . if (ML16 <= -1 )
replace ML16A = . if (ML16A <= -1 )
replace ML17 = . if (ML17 <= -1 )
replace ML18 = . if (ML18 <= -1 )
replace ML19 = . if (ML19 <= -1 )
replace ML20 = . if (ML20 <= -1 )
replace ML21 = . if (ML21 <= -1 )
replace ML22 = . if (ML22 <= -1 )
replace ML22A = . if (ML22A <= -1 )
replace ML23 = . if (ML23 <= -1 )
replace ML23A1 = . if (ML23A1 <= -1 )
replace ML23A2 = . if (ML23A2 <= -1 )
replace ML23A3 = . if (ML23A3 <= -1 )
replace ML23A4 = . if (ML23A4 <= -1 )
replace ML23B = . if (ML23B <= -1 )
replace ML23C = . if (ML23C <= -1 )
replace MM1 = . if (MM1 <= -1 )
replace MM2 = . if (MM2 <= -1 )
replace MM2A1 = . if (MM2A1 <= -1 )
replace MM2A2 = . if (MM2A2 <= -1 )
replace MM2A3 = . if (MM2A3 <= -1 )
replace MM2A4 = . if (MM2A4 <= -1 )
replace MM2A5 = . if (MM2A5 <= -1 )
replace MM3A = . if (MM3A <= -1 )
replace MM3AA = . if (MM3AA <= -1 )
replace MM3BA = . if (MM3BA <= -1 )
replace MM3CA_MO = . if (MM3CA_MO <= -1 )
replace MM3CA_YR = . if (MM3CA_YR <= -1 )
replace MM3DA = . if (MM3DA <= -1 )
replace MM3B = . if (MM3B <= -1 )
replace MM3AB = . if (MM3AB <= -1 )
replace MM3BB = . if (MM3BB <= -1 )
replace MM3CB_MO = . if (MM3CB_MO <= -1 )
replace MM3CB_YR = . if (MM3CB_YR <= -1 )
replace MM3DB = . if (MM3DB <= -1 )
replace MM3C = . if (MM3C <= -1 )
replace MM3AC = . if (MM3AC <= -1 )
replace MM3BC = . if (MM3BC <= -1 )
replace MM3CC_MO = . if (MM3CC_MO <= -1 )
replace MM3CC_YR = . if (MM3CC_YR <= -1 )
replace MM3DC = . if (MM3DC <= -1 )
replace MM3D = . if (MM3D <= -1 )
replace MM3AD = . if (MM3AD <= -1 )
replace MM3BD = . if (MM3BD <= -1 )
replace MM3CD_MO = . if (MM3CD_MO <= -1 )
replace MM3CD_YR = . if (MM3CD_YR <= -1 )
replace MM3DD = . if (MM3DD <= -1 )
replace MM3E = . if (MM3E <= -1 )
replace MM3AE = . if (MM3AE <= -1 )
replace MM3BE = . if (MM3BE <= -1 )
replace MM3CE_MO = . if (MM3CE_MO <= -1 )
replace MM3CE_YR = . if (MM3CE_YR <= -1 )
replace MM3DE = . if (MM3DE <= -1 )
replace MM3F = . if (MM3F <= -1 )
replace MM3AF = . if (MM3AF <= -1 )
replace MM3BF = . if (MM3BF <= -1 )
replace MM3CF_MO = . if (MM3CF_MO <= -1 )
replace MM3CF_YR = . if (MM3CF_YR <= -1 )
replace MM3DF = . if (MM3DF <= -1 )
replace MM4 = . if (MM4 <= -1 )
replace MM4A1 = . if (MM4A1 <= -1 )
replace MM4A2 = . if (MM4A2 <= -1 )
replace MM4A3 = . if (MM4A3 <= -1 )
replace MM4A4 = . if (MM4A4 <= -1 )
replace MM4A5 = . if (MM4A5 <= -1 )
replace MM4A6 = . if (MM4A6 <= -1 )
replace MM5 = . if (MM5 <= -1 )
replace MM5A1 = . if (MM5A1 <= -1 )
replace MM5A2 = . if (MM5A2 <= -1 )
replace MM5A3 = . if (MM5A3 <= -1 )
replace MM5A4 = . if (MM5A4 <= -1 )
replace MM5B = . if (MM5B <= -1 )
replace MM5C = . if (MM5C <= -1 )
replace MM5D = . if (MM5D <= -1 )
replace MM5D_WK = . if (MM5D_WK <= -1 )
replace MM6A = . if (MM6A <= -1 )
replace MM6B = . if (MM6B <= -1 )
replace MM7 = . if (MM7 <= -1 )
replace MM8_1 = . if (MM8_1 <= -1 )
replace MM8_2 = . if (MM8_2 <= -1 )
replace MM8_11 = . if (MM8_11 <= -1 )
replace MM8_12 = . if (MM8_12 <= -1 )
replace MM8_13 = . if (MM8_13 <= -1 )
replace MM8_21 = . if (MM8_21 <= -1 )
replace MM8_22 = . if (MM8_22 <= -1 )
replace MM8_23 = . if (MM8_23 <= -1 )
replace MM8_28 = . if (MM8_28 <= -1 )
replace MM8_91 = . if (MM8_91 <= -1 )
replace MM9 = . if (MM9 <= -1 )
replace MM10 = . if (MM10 <= -1 )
replace MM10A = . if (MM10A <= -1 )
replace MM10B0 = . if (MM10B0 <= -1 )
replace MM10B1 = . if (MM10B1 <= -1 )
replace MM10B2 = . if (MM10B2 <= -1 )
replace MM10B3 = . if (MM10B3 <= -1 )
replace MM10B4 = . if (MM10B4 <= -1 )
replace MM10B5 = . if (MM10B5 <= -1 )
replace MM10B6 = . if (MM10B6 <= -1 )
replace MM10B7 = . if (MM10B7 <= -1 )
replace MM10B8 = . if (MM10B8 <= -1 )
replace MM10B9 = . if (MM10B9 <= -1 )
replace MM10B10 = . if (MM10B10 <= -1 )
replace MM10B11 = . if (MM10B11 <= -1 )
replace MM10B12 = . if (MM10B12 <= -1 )
replace MM10B13 = . if (MM10B13 <= -1 )
replace MM11 = . if (MM11 <= -1 )
replace MM12_1 = . if (MM12_1 <= -1 )
replace MM12_2 = . if (MM12_2 <= -1 )
replace MM12_22 = . if (MM12_22 <= -1 )
replace MM12_23 = . if (MM12_23 <= -1 )
replace MM12_24 = . if (MM12_24 <= -1 )
replace MM12_25 = . if (MM12_25 <= -1 )
replace MM12_26 = . if (MM12_26 <= -1 )
replace MM12_91 = . if (MM12_91 <= -1 )
replace MM13 = . if (MM13 <= -1 )
replace MM14 = . if (MM14 <= -1 )
replace MM15_1 = . if (MM15_1 <= -1 )
replace MM15_2 = . if (MM15_2 <= -1 )
replace MM15_11 = . if (MM15_11 <= -1 )
replace MM15_12 = . if (MM15_12 <= -1 )
replace MM15_13 = . if (MM15_13 <= -1 )
replace MM15_21 = . if (MM15_21 <= -1 )
replace MM15_22 = . if (MM15_22 <= -1 )
replace MM15_23 = . if (MM15_23 <= -1 )
replace MM15_28 = . if (MM15_28 <= -1 )
replace MM15_91 = . if (MM15_91 <= -1 )
replace MM16 = . if (MM16 <= -1 )
replace MM17 = . if (MM17 <= -1 )
replace MM18 = . if (MM18 <= -1 )
replace MM19_1 = . if (MM19_1 <= -1 )
replace MM19_2 = . if (MM19_2 <= -1 )
replace MM19_3 = . if (MM19_3 <= -1 )
replace MM19_4 = . if (MM19_4 <= -1 )
replace MM19_91 = . if (MM19_91 <= -1 )
replace MM20 = . if (MM20 <= -1 )
replace MM21 = . if (MM21 <= -1 )
replace MM22_1 = . if (MM22_1 <= -1 )
replace MM22_2 = . if (MM22_2 <= -1 )
replace MM22_3 = . if (MM22_3 <= -1 )
replace MM22_4 = . if (MM22_4 <= -1 )
replace MM22_91 = . if (MM22_91 <= -1 )
replace MM23 = . if (MM23 <= -1 )
replace MM24 = . if (MM24 <= -1 )
replace MM25_1 = . if (MM25_1 <= -1 )
replace MM25_2 = . if (MM25_2 <= -1 )
replace MM25_3 = . if (MM25_3 <= -1 )
replace MM25_9 = . if (MM25_9 <= -1 )
replace MM26 = . if (MM26 <= -1 )
replace MM27 = . if (MM27 <= -1 )
replace MM28_1 = . if (MM28_1 <= -1 )
replace MM28_2 = . if (MM28_2 <= -1 )
replace MM28_3 = . if (MM28_3 <= -1 )
replace MM28_4 = . if (MM28_4 <= -1 )
replace MM28_9 = . if (MM28_9 <= -1 )
replace MM29 = . if (MM29 <= -1 )
replace MM30 = . if (MM30 <= -1 )
replace MM30A = . if (MM30A <= -1 )
replace MM30B = . if (MM30B <= -1 )
replace MM31 = . if (MM31 <= -1 )
replace MM32 = . if (MM32 <= -1 )
replace MM33 = . if (MM33 <= -1 )
replace MM33A = . if (MM33A <= -1 )
replace MM34 = . if (MM34 <= -1 )
replace MM35 = . if (MM35 <= -1 )
replace MM35A1 = . if (MM35A1 <= -1 )
replace MM35A2 = . if (MM35A2 <= -1 )
replace MM35A3 = . if (MM35A3 <= -1 )
replace MM35A4 = . if (MM35A4 <= -1 )
replace MM35A5 = . if (MM35A5 <= -1 )
replace MM35B1 = . if (MM35B1 <= -1 )
replace MM35B2 = . if (MM35B2 <= -1 )
replace MM35B3 = . if (MM35B3 <= -1 )
replace MM35B4 = . if (MM35B4 <= -1 )
replace MM35B5 = . if (MM35B5 <= -1 )
replace MMD_MO = . if (MMD_MO <= -1 )
replace MMT_HH = . if (MMT_HH <= -1 )
replace MMT_MM = . if (MMT_MM <= -1 )
replace MMAMPM = . if (MMAMPM <= -1 )
replace MN1 = . if (MN1 <= -1 )
replace MN2 = . if (MN2 <= -1 )
replace MN2A = . if (MN2A <= -1 )
replace MN3_1_1 = . if (MN3_1_1 <= -1 )
replace MN3_1_2 = . if (MN3_1_2 <= -1 )
replace MN3_4_1 = . if (MN3_4_1 <= -1 )
replace MN3_4_2 = . if (MN3_4_2 <= -1 )
replace MN4 = . if (MN4 <= -1 )
replace MN4A1 = . if (MN4A1 <= -1 )
replace MN4A2 = . if (MN4A2 <= -1 )
replace MN4A3 = . if (MN4A3 <= -1 )
replace MN4A4 = . if (MN4A4 <= -1 )
replace MN4A5 = . if (MN4A5 <= -1 )
replace MN4A6 = . if (MN4A6 <= -1 )
replace MN5 = . if (MN5 <= -1 )
replace MN6 = . if (MN6 <= -1 )
replace MN6A1 = . if (MN6A1 <= -1 )
replace MN6A2 = . if (MN6A2 <= -1 )
replace MP1 = . if (MP1 <= -1 )
replace MP2 = . if (MP2 <= -1 )
replace MP3 = . if (MP3 <= -1 )
replace MP4 = . if (MP4 <= -1 )
replace MP5 = . if (MP5 <= -1 )
replace MP6 = . if (MP6 <= -1 )
replace MP7 = . if (MP7 <= -1 )
replace MP8 = . if (MP8 <= -1 )
replace MP9 = . if (MP9 <= -1 )
replace MP10A = . if (MP10A <= -1 )
replace MP10B = . if (MP10B <= -1 )
replace MP11A = . if (MP11A <= -1 )
replace MP11B = . if (MP11B <= -1 )
replace MP11C = . if (MP11C <= -1 )
replace MP12A = . if (MP12A <= -1 )
replace MP12B = . if (MP12B <= -1 )
replace MP12C = . if (MP12C <= -1 )
replace MP12D = . if (MP12D <= -1 )
replace MP12E = . if (MP12E <= -1 )
replace MP13 = . if (MP13 <= -1 )
replace MP14A = . if (MP14A <= -1 )
replace MP14B = . if (MP14B <= -1 )
replace MP14C = . if (MP14C <= -1 )
replace MP15A = . if (MP15A <= -1 )
replace MP15B = . if (MP15B <= -1 )
replace MP16 = . if (MP16 <= -1 )
replace MP17 = . if (MP17 <= -1 )
replace MP18A = . if (MP18A <= -1 )
replace MP18B = . if (MP18B <= -1 )
replace MP18C = . if (MP18C <= -1 )
replace MP19 = . if (MP19 <= -1 )
replace MP20 = . if (MP20 <= -1 )
replace MP21 = . if (MP21 <= -1 )
replace MPDM = . if (MPDM <= -1 )
replace MPTH = . if (MPTH <= -1 )
replace MPTM = . if (MPTM <= -1 )
replace MD6C = . if (MD6C <= -1 )
replace ME26 = . if (ME26 <= -1 )
replace MG1A = . if (MG1A <= -1 )
replace AGE = . if (AGE <= -1 )
replace REFER = . if (REFER <= -1 )
replace PDRUGFRQ = . if (PDRUGFRQ <= -1 )
replace DRUGTX = . if (DRUGTX <= -1 )
replace DRGTXAGE = . if (DRGTXAGE <= -1 )
replace MEV_PDRG = . if (MEV_PDRG <= -1 )
replace PDRUG = . if (PDRUG <= -1 )
replace FAVDRUG = . if (FAVDRUG <= -1 )
replace MPAMPM = . if (MPAMPM <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

